@@ -505,7 +505,8 @@ endif
 BUILT_SOURCES += ${GEN_SOURCENAME}/JUnitTests.java
 SCRIPT_BUILT += ${GEN_SOURCENAME}/JUnitTests.java
 TESTS += TestRunner
-noinst_PROGRAMS += TestRunner
+noinst_PROGRAMS += TestRunner Runner JniRunner
+noinst_DATA += TestRunner.jar
 EOF
 echo_LDFLAGS TestRunner
 
@@ -672,8 +673,8 @@ generate_jnixx_class() {
     local suffix=$4
     local j=$(echo $(dirname $dir)/$base)
     if has_java_source $j ; then
-	automake_variable JNIXX_CLASSES += $(echo $j | tr '[/]' '[.]')
-	echo "${dir}/${base}.o: $j.java"
+	echo "jni.hxx jni.cxx: $j.java"
+	echo "${dir}/${base}.o: $j.java | jni.hxx.gch"
     fi
 }
 
@@ -870,7 +871,7 @@ while read file dir base suffix ; do
 	    generate_cni_header $file $dir $base $suffix
 	    generate_compile $file $dir $base $suffix ${sources}
 	    ;;
-	*/jni/*.cxx | */jni/*.cxx-in | */jni/*.cxx-sh | */jnixx/*.cxx )
+	*/jni/*.cxx | */jni/*.cxx-in | */jni/*.cxx-sh | jnixx/*.cxx )
 	    generate_jnixx_class $file $dir $base $suffix
 	    generate_compile $file $dir $base $suffix \
 		lib${GEN_MAKENAME}_jni_a_SOURCES
@@ -889,6 +890,7 @@ echo "" 1>&2
 
 if automake_variable_defined lib${GEN_MAKENAME}_jni_a_SOURCES ; then
     cat <<EOF
+JNIXX_CLASSES = 
 noinst_LIBRARIES += lib${GEN_DIRNAME}-jni.a
 lib${GEN_MAKENAME}_jni_so_SOURCES =
 solib_PROGRAMS += lib${GEN_DIRNAME}-jni.so
@@ -896,20 +898,26 @@ lib${GEN_DIRNAME}-jni.so: lib${GEN_DIRNAME}-jni.a
 .PHONY: jni
 jni: lib${GEN_DIRNAME}-jni.so ${GEN_DIRNAME}.jar
 lib${GEN_MAKENAME}_jni_a_SOURCES += jni.cxx
-jnixx_sources = \$(wildcard \$(root_srcdir)/frysk-sys/frysk/jnixx/*.java)
+jnixx_sources = \$(wildcard \$(root_srcdir)/frysk-sys/jnixx/*.java)
 CLEANFILES += jni.hxx jni.cxx jni.hxx.gch
 \$(lib${GEN_MAKENAME}_jni_a_SOURCES): | jni.hxx jni.hxx.gch
 jni.hxx: \$(jnixx_sources) | ${GEN_DIRNAME}.jar
-	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \
-	    \$(JAVA) frysk.jnixx.Main hxx \$(JNIXX_CLASSES) \
+	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \\
+	    \$(JAVA) jnixx.Main \\
+		hxx \\
+		jni.hxx ${GEN_DIRNAME}.jar \$(JNIXX_CLASSES) \\
 	        > \$@.tmp
 	mv \$@.tmp \$@
 jni.hxx.gch: jni.hxx
-	\$(CXXCOMPILE) -c -x c++-header jni.hxx
-jni.cxx: \$(jnixx_sources) | ${GEN_DIRNAME}.jar jni.hxx.gch
-	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \
-	    \$(JAVA) frysk.jnixx.Main cxx \$(JNIXX_CLASSES) \
+	\$(CXXCOMPILE) -c -x c++-header jni.hxx -o \$@.tmp
+	mv \$@.tmp \$@
+jni.cxx: \$(jnixx_sources) | ${GEN_DIRNAME}.jar
+	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \\
+	    \$(JAVA) jnixx.Main \\
+		cxx \\
+		jni.hxx ${GEN_DIRNAME}.jar \$(JNIXX_CLASSES) \\
 	        > \$@.tmp
 	mv \$@.tmp \$@
+jni.o: jni.hxx | jni.hxx.gch
 EOF
 fi
