@@ -40,10 +40,10 @@
 package frysk.bindir;
 
 import frysk.config.Prefix;
-import frysk.testbed.TearDownExpect;
-import frysk.testbed.TestLib;
 import frysk.proc.Task;
 import frysk.testbed.SlaveOffspring;
+import frysk.testbed.TearDownExpect;
+import frysk.testbed.TestLib;
 
 public class TestFerror extends TestLib {
 
@@ -59,6 +59,24 @@ public class TestFerror extends TestLib {
     }
 
     public void testFerrorTracesPID () {
+	SlaveOffspring child = SlaveOffspring.createChild();
+	Task task = child.findTaskUsingRefresh(true);
+	TearDownExpect e = new TearDownExpect(new String[] {
+		Prefix.binFile("ferror").getAbsolutePath(),
+		"-e",
+		"cloneXX",
+		"--",
+		Integer.toString(task.getProc().getPid())});
+	e.expect("Tracing");
+	child.assertSendAddCloneWaitForAcks();
+	Task clone = child.findTaskUsingRefresh(false);
+	e.expect("Tracing " + clone.getProc().getPid()+"."+clone.getTid() );
+    }
+
+    public void testFerrorTracesPID_MissingSignal () {
+	if(unresolved(6587)){
+	    return;
+	}
 	SlaveOffspring child = SlaveOffspring.createChild();
 	Task task = child.findTaskUsingRefresh(true);
 	TearDownExpect e = new TearDownExpect(new String[] {
