@@ -57,6 +57,11 @@ public class TestFstep extends TestLib {
      * the stepped program.
      */
     public void testFirstStep() throws Exception {
+	
+	if(unresolved(3364)){
+	    return;
+	}
+	
 	Elf e = new Elf(new File("/bin/true"), ElfCommand.ELF_C_READ);
     try {
 	ElfEHeader h = e.getEHeader();
@@ -80,6 +85,10 @@ public class TestFstep extends TestLib {
     
     public void testFstepAcceptsPIDArgument() {
 	
+	if(unresolved(3364)){
+	    return;
+	}
+	
 	// Create an unattached child process.
 	SlaveOffspring child = SlaveOffspring.createChild();
 	Task task = child.findTaskUsingRefresh(true);
