@@ -42,6 +42,7 @@ package frysk.bindir;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.regex.Pattern;
@@ -52,22 +53,28 @@ import gnu.classpath.tools.getopt.OptionGroup;
 import inua.util.PrintWriter;
 
 import frysk.debuginfo.PrintStackOptions;
+import frysk.expr.FQIdentParser;
+import frysk.expr.FQIdentifier;
+import frysk.ftrace.AddrRule;
 import frysk.ftrace.Ftrace;
 import frysk.ftrace.FtraceController;
-import frysk.ftrace.PLTRule;
 import frysk.ftrace.Rule;
+import frysk.ftrace.RuleOptions;
 import frysk.ftrace.SymbolRule;
 import frysk.isa.signals.Signal;
 import frysk.isa.syscalls.Syscall;
 import frysk.proc.Proc;
 import frysk.rsl.Log;
+import frysk.rsl.LogFactory;
 import frysk.util.CommandlineParser;
 import frysk.util.Glob;
 import frysk.util.StackPrintUtil;
 import frysk.util.Util;
 
 class ftrace {
-    private static final Log fine = Log.fine(ftrace.class);
+
+    static private final Log fine = LogFactory.fine(ftrace.class);
+    static private final Log warning = LogFactory.warning(ftrace.class);
 
     //Where to send the output.
     private PrintWriter writer;
@@ -80,8 +87,8 @@ class ftrace {
     // For configuration of overall working set.  We need to load and
     // apply rules separately, to get all log messages, that's the
     // reason we need these temporary array lists.
-    private final List pltRules = new ArrayList();
     private final List symRules = new ArrayList();
+    private final List addrRules = new ArrayList();
     private final List sysRules = new ArrayList();
     private final List sigRules = new ArrayList();
     private final FtraceController controller = new FtraceController();
@@ -91,43 +98,36 @@ class ftrace {
 	= new PrintStackOptions();
     private final Ftrace tracer = new Ftrace(stackPrintOptions);
 
-    private interface SymbolRuleCreator {
-	Rule createRule(boolean addition, boolean stackTrace,
-			String nameRe, String sonameRe, String versionRe);
+    private interface RuleMatcher {
+	void rule(String str, boolean addition, RuleOptions options,
+		  Collection c);
     }
 
-    private List parseSymbolRules(String arg, SymbolRuleCreator creator) {
+    private String parseOptions(String str, RuleOptions opts) {
+	int pos;
+	if ((pos = str.lastIndexOf('/')) != -1) {
+	    String options = str.substring(pos + 1);
+	    str = str.substring(0, pos);
+
+	    for (int j = 0; j < options.length(); ++j) {
+		char opt = options.charAt(j);
+		if (opt == 's')
+		    opts.stackTrace = true;
+		else
+		    warning.log("Unknown rule option", opt);
+	    }
+	}
+	return str;
+    }
+
+    private List parseGenericRules(String arg, RuleMatcher matcher)
+    {
 	String[] strs = arg.split(",", -1);
 	List rules = new ArrayList();
 	for (int i = 0; i < strs.length; ++i) {
-	    // 111 single fully qualified symbol:           'symbol@soname@@version'
-	    // 101 symbol of given version in all dsos:     'symbol@@version'
-	    // 100 symbol of given name from any dso:       'symbol'
-	    // 011 all symbols of given version of the dso: '@soname@@version'
-	    // 010 all symbols of given soname:             '@soname'
-	    // 001 all symbols of given version:            '@@version'
-	    // 000 all symbols of all versions in all dsos: ''
-
 	    String str = strs[i];
-	    final String symbolRe, sonameRe, versionRe;
+
 	    final boolean addition;
-	    final boolean stackTrace;
-	    int pos;
-
-	    if ((pos = str.indexOf("@@")) != -1) {
-		versionRe = str.substring(pos + 2);
-		str = str.substring(0, pos);
-	    }
-	    else
-		versionRe = null;
-
-	    if ((pos = str.indexOf('@')) != -1) {
-		sonameRe = str.substring(pos + 1);
-		str = str.substring(0, pos);
-	    }
-	    else
-		sonameRe = null;
-
 	    if (str.length() > 0 && str.charAt(0) == '-') {
 		addition = false;
 		str = str.substring(1);
@@ -135,27 +135,82 @@ class ftrace {
 	    else
 		addition = true;
 
-	    if (str.length() > 0 && str.charAt(0) == '#') {
-		stackTrace = true;
-		str = str.substring(1);
-	    }
-	    else
-		stackTrace = false;
+	    RuleOptions opts = new RuleOptions();
+	    str = parseOptions(str, opts);
 
-	    if (!str.equals(""))
-		symbolRe = str;
-	    else
-		symbolRe = null;
-
-	    fine.log(i + ": " + str + ": symbol=" + symbolRe
-		     + ", soname=" + sonameRe + ", version=" + versionRe);
-	    Rule rule = creator.createRule(addition, stackTrace,
-					   symbolRe, sonameRe, versionRe);
-	    rules.add(rule);
+	    matcher.rule(str, addition, opts, rules);
 	}
 	return rules;
     }
 
+    private List parseSymbolRules(String arg) {
+	return parseGenericRules(arg, new RuleMatcher() {
+		public void rule(String str, boolean addition,
+				 RuleOptions options, Collection rules) {
+
+		    try {
+			FQIdentifier fqid = FQIdentParser.parseFtraceIdentifier(str);
+			rules.add(new SymbolRule(addition, options, fqid));
+		    }
+		    catch (FQIdentParser.ExtraGarbageException exc) {
+			warning.log("Ignoring garbage after the end of the symbol rule",
+				    exc.getMessage());
+		    }
+		    catch (FQIdentParser.InvalidTokenException exc) {
+			warning.log("Invalid symbol rule", exc.getMessage());
+		    }
+		}
+	    });
+    }
+
+    private final static Pattern addressPat = Pattern.compile("(0x)?[0-9a-fA-F]+");
+    private final static Pattern sysnumPat = Pattern.compile("[0-9]+");
+
+    private List parseAddrRules(String arg) {
+	return parseGenericRules(arg, new RuleMatcher() {
+		String lastSoname = null;
+
+		public void rule(String str, boolean addition,
+				 RuleOptions options, Collection rules) {
+
+		    // [#soname#]address.  If soname is omitted, then
+		    // previous is reused.
+		    String addressS, sonameRe;
+
+		    if (str.length() > 0 && str.charAt(0) == '#') {
+			int pos = str.indexOf('#', 1);
+			if (pos == -1 || str.indexOf('#', pos+1) != -1) {
+			    warning.log("Ignoring address rule with mangled soname component:", str);
+			    return;
+			}
+			sonameRe = str.substring(1, pos);
+			addressS = str.substring(pos + 1);
+		    } else {
+			sonameRe = lastSoname;
+			addressS = str;
+		    }
+
+		    if (sonameRe == null) {
+			warning.log("Ignoring address rule with unknown soname context:", str);
+			return;
+		    }
+
+		    if (!addressPat.matcher(addressS).matches()) {
+			warning.log("Ignoring rule with mangled or missing address component:", str);
+			return;
+		    }
+
+		    if (addressS.startsWith("0x"))
+			addressS = addressS.substring(2);
+		    long addr = Long.parseLong(addressS, 16);
+
+		    fine.log(str + ": address=" + Long.toHexString(addr)
+			     + ", soname=" + sonameRe);
+		    rules.add(new AddrRule(addition, options, addr, sonameRe));
+		}
+	    });
+    }
+
     private static interface TraceableExaminer {
 	int traceableNumber(Object traceable);
 	String traceableName(Object traceable);
@@ -165,7 +220,6 @@ class ftrace {
 				  String optionalPrefix)
     {
 	String[] strs = arg.split(",", -1);
-	Pattern sysnumPat = Pattern.compile("[0-9]+");
 	List rules = new ArrayList();
 	for (int i = 0; i < strs.length; ++i) {
 	    // "14": traceable number 14
@@ -174,7 +228,6 @@ class ftrace {
 	    String str = strs[i];
 	    final Rule rule;
 	    final boolean addition;
-	    final boolean stackTrace;
 
 	    if (str.length() > 0 && str.charAt(0) == '-') {
 		addition = false;
@@ -183,17 +236,14 @@ class ftrace {
 	    else
 		addition = true;
 
-	    if (str.length() > 0 && str.charAt(0) == '#') {
-		stackTrace = true;
-		str = str.substring(1);
-	    }
-	    else
-		stackTrace = false;
+	    RuleOptions opts = new RuleOptions();
+	    str = parseOptions(str, opts);
 
 	    final String ruleKern = new String(str);
+
 	    abstract class SigSysRule extends Rule {
-		public SigSysRule(boolean addition, boolean stackTrace) {
-		    super(addition, stackTrace);
+		public SigSysRule(boolean addition, RuleOptions options) {
+		    super(addition, options);
 		}
 		public String toString() {
 		    return super.toString() + ruleKern;
@@ -203,7 +253,7 @@ class ftrace {
 	    if (sysnumPat.matcher(str).matches()) {
 		fine.log(i + ": " + str + ": by number rule");
 		final int number = (new Integer(str)).intValue();
-		rule = new SigSysRule(addition, stackTrace) {
+		rule = new SigSysRule(addition, opts) {
 			public boolean matches(final Object traceable) {
 			    return number == examiner.traceableNumber(traceable);
 			}
@@ -215,7 +265,7 @@ class ftrace {
 		if (optionalPrefix != null && !str.startsWith(optionalPrefix))
 		    str = optionalPrefix + str;
 		final Pattern pattern = Glob.compile(str, Pattern.CASE_INSENSITIVE);
-		rule = new SigSysRule(addition, stackTrace) {
+		rule = new SigSysRule(addition, opts) {
 			public boolean matches(final Object traceable) {
 			    String name = examiner.traceableName(traceable);
 			    return pattern.matcher(name).matches();
@@ -224,7 +274,7 @@ class ftrace {
 	    }
 	    else {
 		fine.log(i + ": " + str + ": \"everything\" rule");
-		rule = new SigSysRule(addition, stackTrace) {
+		rule = new SigSysRule(addition, opts) {
 			public boolean matches(Object traceable) {
 			    return true;
 			}
@@ -293,16 +343,16 @@ class ftrace {
 		    sysRules.add(arg);
 		}
 	    });
-	group.add(new Option("plt", "trace library calls done via PLT", "RULE[,RULE]...") {
-		public void parsed(String arg) {
-		    pltRules.add(arg);
-		}
-	    });
 	group.add(new Option("sym", "trace function entry points", "RULE[,RULE]...") {
 		public void parsed(String arg) {
 		    symRules.add(arg);
 		}
 	    });
+	group.add(new Option("addr", "trace address inside the binary", "RULE[,RULE]...") {
+		public void parsed(String arg) {
+		    addrRules.add(arg);
+		}
+	    });
 	group.add(new Option("stack", "stack trace on every traced entity") {
 		public void parsed(String arg) {
 		    controller.stackTraceEverything();
@@ -340,41 +390,21 @@ class ftrace {
             writer = new PrintWriter(System.out);
         tracer.setWriter(writer);
 
-	if (!pltRules.isEmpty() || !symRules.isEmpty()) {
+	if (!symRules.isEmpty() || !addrRules.isEmpty()) {
 	    // If tracing dynamic linker disabled, generate implicit
-	    // -@INTERP rule at the end of the chain.
-	    if (!allowInterpTracing) {
-		pltRules.add("-@INTERP");
-		symRules.add("-@INTERP");
-	    }
+	    // inhibition rules at the end of the chain.
+	    if (!allowInterpTracing)
+		symRules.add("-#INTERP#*");
 
-	    class SymbolCreator implements SymbolRuleCreator {
-		public Rule createRule(boolean addition, boolean stackTrace,
-				       String nameRe, String sonameRe,
-				       String versionRe) {
-		    return new SymbolRule(addition, stackTrace,
-					  nameRe, sonameRe, versionRe);
-		}
-	    }
-	    SymbolRuleCreator symbolCreator = new SymbolCreator();
+	    // Symbol tracing
 	    for (Iterator it = symRules.iterator(); it.hasNext(); ) {
-		List rules = parseSymbolRules((String)it.next(), symbolCreator);
+		List rules = parseSymbolRules((String)it.next());
 		controller.gotSymRules(rules);
 	    }
 
-	    class PLTCreator implements SymbolRuleCreator {
-		public Rule createRule(boolean addition, boolean stackTrace,
-				       String nameRe, String sonameRe,
-				       String versionRe) {
-		    return new PLTRule(addition, stackTrace,
-				       nameRe, sonameRe, versionRe);
-		}
-	    }
-	    SymbolRuleCreator pltCreator = new PLTCreator();
-	    for (Iterator it = pltRules.iterator(); it.hasNext(); ) {
-		List rules = parseSymbolRules((String)it.next(), pltCreator);
-		controller.gotPltRules(rules);
-	    }
+	    // Address tracing
+	    for (Iterator it = addrRules.iterator(); it.hasNext(); )
+		controller.gotAddrRules(parseAddrRules((String)it.next()));
 
 	    tracer.setTraceFunctions(controller, controller);
 	}
