@@ -39,6 +39,7 @@
 
 package frysk.debuginfo;
 
+import frysk.expr.ExprSearchEngine;
 import frysk.expr.ExpressionFactory;
 import frysk.dwfl.DwflCache;
 import frysk.proc.Proc;
@@ -51,7 +52,7 @@ import lib.dwfl.DwarfException;
 import lib.dwfl.Dwfl;
 import lib.dwfl.DwTag;
 import lib.dwfl.DwAt;
-import lib.dwfl.DwflDieBias;
+import lib.dwfl.DwflDie;
 import lib.dwfl.Elf;
 import lib.dwfl.ElfCommand;
 import java.io.File;
@@ -84,15 +85,13 @@ public class DebugInfo {
     public String what(DebugInfoFrame frame, String sInput) {
 	long pc = frame.getAdjustedAddress();
 	Dwfl dwfl = DwflCache.getDwfl(frame.getTask());
-	DwflDieBias bias = dwfl.getCompilationUnit(pc);
+	DwflDie bias = dwfl.getCompilationUnit(pc);
 	TypeFactory typeFactory = new TypeFactory(frame.getTask().getISA());
 	if (bias == null)
 	    throw new RuntimeException("No symbol table is available.");
-	DwarfDie die = bias.die;
 	StringBuffer result = new StringBuffer();
-
-	DwarfDie[] allDies = die.getScopes(pc - bias.bias);
-	DwarfDie varDie = die.getScopeVar(allDies, sInput);
+	DwarfDie[] allDies = bias.getScopes(pc);
+	DwarfDie varDie = bias.getScopeVar(allDies, sInput);
 	if (varDie == null) {
 	    varDie = DwarfDie.getDecl(dwarf, sInput);
 	    if (varDie == null)
@@ -138,8 +137,8 @@ public class DebugInfo {
      * Implement the cli print request.
      */
     public Value print(String expression, DebugInfoFrame frame) {
-	ObjectDeclarationSearchEngine symTab
-	    = new ObjectDeclarationSearchEngine(frame);
+	ExprSearchEngine symTab
+	    = new ExprSearchEngine(frame);
 	return ExpressionFactory.parse(symTab, expression).getValue();
     }
    
