@@ -40,11 +40,12 @@
 package frysk.debuginfo;
 
 import java.io.PrintWriter;
+import java.util.Iterator;
 import java.util.LinkedList;
 
 import lib.dwfl.DwarfDie;
 import lib.dwfl.Dwfl;
-import lib.dwfl.DwflDieBias;
+import lib.dwfl.DwflDie;
 import frysk.dwfl.DwflCache;
 import frysk.rt.LineXXX;
 import frysk.scopes.Function;
@@ -86,11 +87,11 @@ public class DebugInfoFrame extends FrameDecorator {
 	
 	if (scope == null) {
 	    Dwfl dwfl = DwflCache.getDwfl(this.getTask());
-	    DwflDieBias bias = dwfl.getCompilationUnit(getAdjustedAddress());
+	    DwflDie bias = dwfl.getCompilationUnit(getAdjustedAddress());
 
 	    if (bias != null) {
 
-		DwarfDie[] scopes = bias.die.getScopes(getAdjustedAddress());
+		DwarfDie[] scopes = bias.getScopes(getAdjustedAddress());
 		
 		if (scopes.length == 0) {
 		    return null;
@@ -132,11 +133,11 @@ public class DebugInfoFrame extends FrameDecorator {
 	  this.inlinedSubprograms = new LinkedList();
 	  
         Dwfl dwfl = DwflCache.getDwfl(this.getTask());
-        DwflDieBias bias = dwfl.getCompilationUnit(getAdjustedAddress());
+        DwflDie bias = dwfl.getCompilationUnit(getAdjustedAddress());
 
         if (bias != null) {
 
-            DwarfDie[] scopes = bias.die.getScopes(getAdjustedAddress());
+            DwarfDie[] scopes = bias.getScopes(getAdjustedAddress());
             
             if(scopes.length == 0){
         	return inlinedSubprograms;
@@ -221,17 +222,20 @@ public class DebugInfoFrame extends FrameDecorator {
         }
     }
     
-    void printScopes(PrintWriter writer) {
+    public void printScopes(PrintWriter writer) {
 	printScope(writer, getSubprogram(), " ");
     }
 
     private void printScope(PrintWriter writer, Scope scope, String indentString) {
-	
+
 	if (scope != null) {
-	    writer.print(indentString + "{");
+	    writer.print(indentString + "{"); 
 	    scope.toPrint(this, writer, indentString);
-	    if(!(scope.getInner() instanceof Function && ((Function)scope.getInner()).isInlined())){
-		printScope(writer, scope.getInner(), indentString+" ");
+
+	    Iterator innerScopes = scope.getScopes().iterator();
+	    while (innerScopes.hasNext()) {
+		Scope innerScope = (Scope) innerScopes.next(); 
+		printScope(writer, innerScope, indentString+" ");
 	    }
 	    writer.println(indentString+"}");
 	}
