@@ -79,11 +79,11 @@ public class TestAddress
     {
 	DebugInfoFrame frame = DebugInfoStackFactory.createDebugInfoStackTrace
 	                       (getStoppedTask());
-	ObjectDeclarationSearchEngine declarationSearchEngine = new ObjectDeclarationSearchEngine(frame);
+	ObjectDeclarationSearchEngine declarationSearchEngine = new ObjectDeclarationSearchEngine(getStoppedTask());
 	
 	/* Evaluate the location of the variable.
 	 */ 
-	Variable var = (Variable) declarationSearchEngine.getObjectInScope(variable);
+	Variable var = (Variable) declarationSearchEngine.getObjectInScope(frame, variable);
 	DwarfDie varDie = var.getVariableDie();
 	List ops = varDie.getFormData(frame.getAdjustedAddress());
 	LocationExpression locExpr = new LocationExpression(varDie);
@@ -92,7 +92,7 @@ public class TestAddress
 
 	 /* Get the value of the address.
 	 */
-	Variable addr = (Variable) declarationSearchEngine.getObjectInScope(address);
+	Variable addr = (Variable) declarationSearchEngine.getObjectInScope(frame, address);
 	DwarfDie addrDie = addr.getVariableDie();
 	List opsAddr = addrDie.getFormData(frame.getAdjustedAddress());
 	LocationExpression locExprAddr = new LocationExpression(
