@@ -43,21 +43,23 @@ import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.util.Iterator;
 import java.util.LinkedList;
+
 import javax.naming.NameNotFoundException;
+
 import lib.dwfl.DwTag;
 import lib.dwfl.DwarfDie;
 import lib.dwfl.Dwfl;
-import lib.dwfl.DwflDieBias;
+import lib.dwfl.DwflDie;
 import frysk.dwfl.DwflCache;
 import frysk.proc.Task;
+import frysk.scopes.Function;
 import frysk.scopes.LexicalBlock;
 import frysk.scopes.Scope;
-import frysk.scopes.Function;
+import frysk.scopes.Variable;
 import frysk.stack.Frame;
 import frysk.stack.StackFactory;
 import frysk.testbed.DaemonBlockedAtSignal;
 import frysk.testbed.TestLib;
-import frysk.scopes.Variable;
 
 public class TestFrameDebugInfo extends TestLib {
 
@@ -181,8 +183,8 @@ public class TestFrameDebugInfo extends TestLib {
     Frame frame = StackFactory.createFrame(task);
     
     Dwfl dwfl = DwflCache.getDwfl(task);
-    DwflDieBias bias = dwfl.getCompilationUnit(frame.getAdjustedAddress());
-    DwarfDie[] scopes = bias.die.getScopes(frame.getAdjustedAddress() - bias.bias);
+    DwflDie bias = dwfl.getCompilationUnit(frame.getAdjustedAddress());
+    DwarfDie[] scopes = bias.getScopes(frame.getAdjustedAddress());
     
     assertEquals("number of scopes", 3, scopes.length);
     
@@ -245,8 +247,8 @@ public class TestFrameDebugInfo extends TestLib {
     Frame frame = StackFactory.createFrame(task);
     
     Dwfl dwfl = DwflCache.getDwfl(task);
-    DwflDieBias bias = dwfl.getCompilationUnit(frame.getAdjustedAddress());
-    DwarfDie[] scopes = bias.die.getScopes(frame.getAdjustedAddress() - bias.bias);
+    DwflDie bias = dwfl.getCompilationUnit(frame.getAdjustedAddress());
+    DwarfDie[] scopes = bias.getScopes(frame.getAdjustedAddress());
     scopes = scopes[0].getScopesDie();
     
     assertEquals("number of scopes", 4, scopes.length);
@@ -319,6 +321,26 @@ public class TestFrameDebugInfo extends TestLib {
     assertTrue("contains main", stringWriter.getBuffer().toString().contains("main"));
   }
   
+  public void testVirtualStackTraceWithLocals()
+  {
+    
+      Task task = (new DaemonBlockedAtSignal("funit-stack-inlined")).getMainTask();
+    
+    PrintStackOptions options = new PrintStackOptions();
+    options.setNumberOfFrames(0); 
+    options.setPrintParams(true);
+    options.setPrintLocals(true);
+    options.setPrintFullPaths(true);
+    
+    DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
+    frame = frame.getOuterDebugInfoFrame();
+    
+    StringWriter stringWriter = new StringWriter();
+    frame.printScopes(new PrintWriter(stringWriter));
+    
+    assertTrue("Contains var2", stringWriter.getBuffer().toString().contains("var2"));
+  }
+  
   public void testInlinedFunctionDerailment()
   {
     inlinedFunctionDerailment("");
