@@ -63,12 +63,12 @@ public class TestGccClass extends TestCase {
 	log.log(this, "Got debug frame: ", frame);
 
 	ObjectDeclarationSearchEngine objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(
-		frame);
+		task);
 	
 	log.log(this, "Got search engine: ", objectDeclarationSearchEngine);
 
 	Variable variable = (Variable) objectDeclarationSearchEngine
-		.getObjectInScope(variableName);
+		.getObjectInScope(frame, variableName);
 
 	assertNotNull("Variable found", variable);
 	
