@@ -123,9 +123,9 @@ public class TestObjectDeclarationSearchEngine extends TestLib{
 	
 	Task task = (new DaemonBlockedAtSignal(fileName)).getMainTask();
     	DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-    	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(frame);
+    	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(task);
     	
-    	ObjectDeclaration declaredObject = objectDeclarationSearchEngine.getObjectInScope(variableName);
+    	ObjectDeclaration declaredObject = objectDeclarationSearchEngine.getObjectInScope(frame, variableName);
  
     	assertEquals("Object has the correct name", declaredObject.getName(), variableName);
 
@@ -152,7 +152,7 @@ public class TestObjectDeclarationSearchEngine extends TestLib{
     public void testFindFirstElfSymbols(){
 	String variableName = "first"; 
 	String fileName = "funit-elf-symbols";
-	String valueString = "{12,34,56,78}";
+	String valueString = "12,34,56,78";
 	
 	verifyVariableByValue(variableName, valueString, fileName);
 	
@@ -187,8 +187,8 @@ public class TestObjectDeclarationSearchEngine extends TestLib{
 	int variableLine = scanner.findTokenLine(variableToken);
 	Task task = (new DaemonBlockedAtSignal(fileName)).getMainTask();
 	DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
-	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(frame);
-	ObjectDeclaration objectDeclaration = (ObjectDeclaration) objectDeclarationSearchEngine.getObjectInScope(variableName);
+	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(task);
+	ObjectDeclaration objectDeclaration = (ObjectDeclaration) objectDeclarationSearchEngine.getObjectInScope(frame, variableName);
 
 	assertNotNull("Variable found", objectDeclaration);
 	assertEquals("Correct name", variableName, objectDeclaration.getName() );
@@ -196,7 +196,7 @@ public class TestObjectDeclarationSearchEngine extends TestLib{
 	
 	//Negative test:
 	try {
-	    objectDeclaration = (Variable) objectDeclarationSearchEngine.getObjectInScope("NOT"+variableName);
+	    objectDeclaration = (Variable) objectDeclarationSearchEngine.getObjectInScope(frame, "NOT"+variableName);
 	    assertTrue("Exception was not thrown", false);
 	} catch (ObjectDeclarationNotFoundException e) {
 	    // exception was thrown
@@ -231,16 +231,16 @@ public class TestObjectDeclarationSearchEngine extends TestLib{
 	Task task = (new DaemonBlockedAtSignal(fileName)).getMainTask();
 	DebugInfoFrame frame = DebugInfoStackFactory.createVirtualStackTrace(task);
 	assertNotNull("frame object created",  frame);
-	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(frame);
-	ObjectDeclaration objectDeclaration = (ObjectDeclaration) objectDeclarationSearchEngine.getObjectInScope(variableName);
+	objectDeclarationSearchEngine = new ObjectDeclarationSearchEngine(task);
+	ObjectDeclaration objectDeclaration = (ObjectDeclaration) objectDeclarationSearchEngine.getObjectInScope(frame, variableName);
 
 	assertNotNull("Variable found", objectDeclaration);
 	assertEquals("Correct name", variableName, objectDeclaration.getName() );
-	assertEquals("Variable value", valueString, objectDeclaration.getValue(frame).toPrint());
+	assertTrue("Variable value", objectDeclaration.getValue(frame).toPrint().contains(valueString));
 	
 	//Negative test:
 	try {
-	    objectDeclaration = (Variable) objectDeclarationSearchEngine.getObjectInScope("NOT"+variableName);
+	    objectDeclaration = (Variable) objectDeclarationSearchEngine.getObjectInScope(frame, "NOT"+variableName);
 	    assertTrue("Exception was not thrown", false);
 	} catch (ObjectDeclarationNotFoundException e) {
 	    // exception was thrown
