@@ -41,7 +41,6 @@ package frysk.ftrace;
 
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -66,7 +65,7 @@ import frysk.rsl.LogFactory;
 import frysk.stepping.SteppingEngine;
 import frysk.symtab.DwflSymbol;
 import frysk.symtab.PLTEntry;
-import frysk.symtab.SymbolFactory;
+import frysk.util.ArchFormatter;
 
 import lib.dwfl.Dwfl;
 import lib.dwfl.DwflModule;
@@ -74,6 +73,7 @@ import lib.dwfl.DwflModule;
 public class Ftrace {
     static private final Log fine = LogFactory.fine(Ftrace.class);
     static private final Log finest = LogFactory.finest(Ftrace.class);
+    static private final Log warning = LogFactory.warning(Ftrace.class);
 
     private final PrintStackOptions stackPrintOptions;
 
@@ -107,8 +107,14 @@ public class Ftrace {
 	 * ltrace what to do.
 	 */
 	void fileMapped(Task task, ObjectFile objf,
-			List symbols, List pltEntries,
-			Driver driver);
+			DwflModule module, Driver driver);
+
+	/**
+	 * New library FILE was unmapped from task TASK.  Use DRIVER
+	 * to tell ltrace what to do.
+	 */
+	void fileUnmapped(Task task, ObjectFile objf,
+			  DwflModule module, Driver driver);
     }
 
     /**
@@ -152,6 +158,8 @@ public class Ftrace {
     public static interface Driver {
 	void traceSymbol(Task task, DwflSymbol symbol);
 	void tracePLTEntry(Task task, PLTEntry entry);
+	void traceAddress(Task task, Long addrToken, long bias, ObjectFile objf);
+	void untrace(Task task, List traceables);
     }
 
     // Non-null if we're using ltrace.
@@ -226,38 +234,55 @@ public class Ftrace {
 	Manager.eventLoop.run();
     }
 
+    class TaskObservations {
+	boolean locked = false;
+	int counter = 1;
+    }
+
     private HashMap observationCounters = new HashMap();
 
-    synchronized private void observationRequested(Task task) {
-	Integer i = (Integer)observationCounters.get(task);
-	if (i == null)
-	    i = new Integer(1);
+    synchronized private void observationRequested(Task task, String what) {
+	fine.log("Observation requested", what);
+	TaskObservations to = (TaskObservations)observationCounters.get(task);
+	if (to == null)
+	    observationCounters.put(task, new TaskObservations());
+	else if (to.locked)
+	    warning.log("Attempt to add new observation to locked task.");
 	else
-	    i = new Integer(i.intValue() + 1);
-	observationCounters.put(task, i);
+	    to.counter++;
     }
 
-    synchronized private void observationRealized(Task task) {
-	Integer i = (Integer)observationCounters.get(task);
-	// must be non-null
-	int j = i.intValue();
-	if (j == 1) {
-	    // Store a dummy into the map to detect errors.
-	    observationCounters.put(task, new Object());
-	    task.requestUnblock(attachedObserver);
+    synchronized private void observationRealized(Task task, String what) {
+	fine.log("Observation realized", what);
+	TaskObservations to = (TaskObservations)observationCounters.get(task);
+	if (to == null || to.counter < 0)
+	    warning.log("Observation realization for invalid task.");
+	else {
+	    to.counter--;
+	    if (to.counter == 0 && to.locked)
+		task.requestUnblock(attachedObserver);
 	}
-	else
-	    observationCounters.put(task, new Integer(--j));
     }
 
-    synchronized void handleTask (Task task)
-    {
+    synchronized private void noMoreObservations(Task task) {
+	TaskObservations to = (TaskObservations)observationCounters.get(task);
+	if (to == null || to.locked || to.counter < 0)
+	    warning.log("Attempt to lock invalid or locked task.");
+	else {
+	    to.locked = true;
+	    if (to.counter == 0)
+		task.requestUnblock(attachedObserver);
+	}
+    }
+
+    synchronized void handleTask(Task task) {
+
 	Proc proc = task.getProc();
 
 	if (tracedSyscallProvider != null) {
 	    finest.log("requesting syscall observer");
 	    task.requestAddSyscallsObserver(new MySyscallObserver(reporter));
-	    observationRequested(task);
+	    observationRequested(task, "syscall");
 	    Map workingSet
 		= tracedSyscallProvider.computeSyscallWorkingSet(task);
 	    syscallSetForTask.put(task, workingSet);
@@ -266,36 +291,37 @@ public class Ftrace {
 	if (tracedSignalProvider != null) {
 	    finest.log("requesting signal observer");
 	    task.requestAddSignaledObserver(new MySignaledObserver());
-	    observationRequested(task);
+	    observationRequested(task, "signal");
 	    Map workingSet
 		= tracedSignalProvider.computeSignalWorkingSet(task);
 	    signalSetForTask.put(task, workingSet);
 	}
 
 	task.requestAddForkedObserver(forkedObserver);
-	observationRequested(task);
+	observationRequested(task, "forked");
 
 	task.requestAddClonedObserver(clonedObserver);
-	observationRequested(task);
+	observationRequested(task, "cloned");
 
 	task.requestAddTerminatingObserver(new MyTerminatingObserver());
-	observationRequested(task);
+	observationRequested(task, "terminating");
 
 	if (ftraceController != null || traceMmapUnmap) {
 	    MyMappingObserver o = new MyMappingObserver(ftraceController);
 
-	    // Presumably the user would like to see mappings and
-	    // unmappings as precisely as possible, and all of them.
-	    // Use syscall-based observer in that case.
 	    if (traceMmapUnmap)
+		// Presumably the user would like to see mappings and
+    		// unmappings as precisely as possible, and all of
+    		// them.  Use syscall-based observer in that case.
 		MappingGuard.requestAddSyscallBasedMappingObserver(task, o);
 	    else
 		MappingGuard.requestAddMappingObserver(task, o);
-	    observationRequested(task);
+	    observationRequested(task, "mapping");
 	}
 
 	new ProcRemovedObserver(proc);
 
+	noMoreObservations(task);
 	reporter.eventSingle(task, "attached " + proc.getExeFile().getSysRootedPath());
 	++numProcesses;
     }
@@ -387,11 +413,11 @@ public class Ftrace {
 			public void run() {
 			    finest.log("Attaching breakpoint manager");
 			    steppingEngine.getBreakpointManager().manageProcess(proc);
-			    observationRealized(task);
+			    observationRealized(task, "breakpoint manager");
 			}
 		    }
 		    Manager.eventLoop.add(new AddProcToBreakpointManager());
-		    observationRequested(task);
+		    observationRequested(task, "breakpoint manager");
 		}
 
 		addProc(task.getProc());
@@ -464,9 +490,8 @@ public class Ftrace {
 
 	public void addedTo (Object observable)
 	{
-	    finest.log("syscall observer realized");
 	    Task task = (Task) observable;
-	    observationRealized(task);
+	    observationRealized(task, "syscall");
 	}
 
 	public void addFailed (Object observable, Throwable w)
@@ -487,7 +512,7 @@ public class Ftrace {
 	public void addedTo (Object observable)
 	{
 	    Task task = (Task) observable;
-	    observationRealized(task);
+	    observationRealized(task, "clone");
 	}
 
 	public void deletedFrom (Object observable)
@@ -553,7 +578,7 @@ public class Ftrace {
 
 	public void addedTo (Object observable) {
 	    Task task = (Task) observable;
-	    observationRealized(task);
+	    observationRealized(task, "terminating");
 	}
 	public void deletedFrom (Object observable) { }
 	public void addFailed (Object observable, Throwable w) { }
@@ -577,9 +602,8 @@ public class Ftrace {
 	}
 
 	public void addedTo (Object observable) {
-	    finest.log("signal observer realized for " + observable);
 	    Task task = (Task) observable;
-	    observationRealized(task);
+	    observationRealized(task, "signal");
 	}
 	public void deletedFrom (Object observable) {
 	    finest.log("signal observer deleted from " + observable);
@@ -600,7 +624,7 @@ public class Ftrace {
 
 	private DwflModule getModuleForFile(Task task, String path) {
 	    Dwfl dwfl = frysk.dwfl.DwflCache.getDwfl(task);
-	    DwflModule[] modules = dwfl.getModulesForce();
+	    DwflModule[] modules = dwfl.getModules();
 	    for (int i = 0; i < modules.length; ++i) {
 		String name = modules[i].getName();
 		if (name.equals(path))
@@ -609,66 +633,97 @@ public class Ftrace {
 	    return null;
 	}
 
-	public Action updateMappedFile(Task task, MemoryMapping mapping)
-	{
-	    String path = mapping.path;
-	    if (traceMmapUnmap)
-		reporter.eventSingle(task, "map " + path);
+	private void reportMapUnmap(Task task, MemoryMapping mapping, String what) {
 
-	    if (this.tracingController == null)
-		return Action.CONTINUE;
+	    MemoryMapping.Part part0 = (MemoryMapping.Part)mapping.parts.get(0);
 
-	    if (path.equals("/SYSV00000000 (deleted)")) {
+	    long addr = part0.addressLow;
+	    String event = what
+		+ ' ' + ArchFormatter.toHexString(task, addr)
+		+ ' ' + mapping.path;
+
+	    reporter.eventSingle(task, event);
+	}
+
+	private ObjectFile objectFileForMapping(MemoryMapping mapping) {
+	    if (mapping.path.equals("/SYSV00000000 (deleted)"))
 		// This is most probably artificial name of SYSV
 		// shared memory "file".
-		return Action.CONTINUE;
-	    }
-	    ObjectFile objf = ObjectFile.buildFromFile(mapping.path);
-	    if (objf == null)
-		return Action.CONTINUE;
+		return null;
 
-	    DwflModule module = getModuleForFile(task, path);
-	    Map symbolTable = SymbolFactory.getSymbolTable(module);
-	    List pltEntries = SymbolFactory.getPLTEntries(module, symbolTable);
-	    List symbols = new ArrayList(symbolTable.values());
-	    if (symbols.size() == 0)
-		// In that case we also know there are no PLT entries,
-		// because each PLT entry is defined on a symbol.
-		return Action.CONTINUE;
+	    return ObjectFile.buildFromFile(mapping.path);
+	}
 
+	private Map getDriversForTask(Task task) {
 	    Map drivers = (Map)driversForTask.get(task);
 	    if (drivers == null) {
 		drivers = new HashMap();
 		driversForTask.put(task, drivers);
 	    }
+	    return drivers;
+	}
+
+	public Action updateMappedFile(Task task, MemoryMapping mapping) {
+
+	    if (traceMmapUnmap)
+		reportMapUnmap(task, mapping, "map");
+
+	    if (this.tracingController == null)
+		return Action.CONTINUE;
+
+	    ObjectFile objf = objectFileForMapping(mapping);
+	    if (objf == null)
+		return Action.CONTINUE;
+
+	    DwflModule module = getModuleForFile(task, mapping.path);
+
+	    Map drivers = getDriversForTask(task);
 	    Driver driver = new TaskTracer(Ftrace.this, task);
 	    drivers.put(mapping.path, driver);
-	    this.tracingController.fileMapped(task, objf, symbols, pltEntries, driver);
+	    this.tracingController.fileMapped(task, objf, module, driver);
 
 	    task.requestUnblock(this);
 	    return Action.BLOCK;
 	}
 
-	public Action updateUnmappedFile(frysk.proc.Task task, MemoryMapping mapping)
-	{
+	public Action updateUnmappedFile(frysk.proc.Task task,
+					 MemoryMapping mapping)	{
 	    if (traceMmapUnmap)
-		reporter.eventSingle(task, "unmap " + mapping.path);
-	    return Action.CONTINUE;
+		reportMapUnmap(task, mapping, "unmap");
+
+	    if (this.tracingController == null)
+		return Action.CONTINUE;
+
+	    ObjectFile objf = objectFileForMapping(mapping);
+	    if (objf == null)
+		return Action.CONTINUE;
+
+	    DwflModule module = getModuleForFile(task, mapping.path);
+
+	    Map drivers = getDriversForTask(task);
+	    Driver driver = (Driver)drivers.get(mapping.path);
+	    if (driver == null)
+		throw new AssertionError("There should be a driver for `" + mapping.path + "'.");
+
+	    this.tracingController.fileUnmapped(task, objf, module, driver);
+
+	    task.requestUnblock(this);
+	    return Action.BLOCK;
 	}
 
-	public Action updateMappedPart(Task task, MemoryMapping mapping, MemoryMapping.Part part)
-	{
+	public Action updateMappedPart(Task task, MemoryMapping mapping,
+				       MemoryMapping.Part part) {
 	    return Action.CONTINUE;
     	}
 
-	public Action updateUnmappedPart(Task task, MemoryMapping mapping, MemoryMapping.Part part)
-	{
+	public Action updateUnmappedPart(Task task, MemoryMapping mapping,
+					 MemoryMapping.Part part) {
 	    return Action.CONTINUE;
     	}
 
 	public void addedTo (Object observable) {
 	    Task task = (Task) observable;
-	    observationRealized(task);
+	    observationRealized(task, "mapping");
 	}
 	public void deletedFrom (Object observable) { }
 	public void addFailed (Object observable, Throwable w) { }
