@@ -47,6 +47,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import lib.dwfl.DwflModule;
+import lib.dwfl.ModuleElfBias;
+
 import frysk.dwfl.ObjectFile;
 import frysk.isa.signals.SignalTable;
 import frysk.isa.syscalls.SyscallTable;
@@ -55,6 +58,7 @@ import frysk.rsl.Log;
 import frysk.rsl.LogFactory;
 import frysk.symtab.DwflSymbol;
 import frysk.symtab.PLTEntry;
+import frysk.symtab.SymbolFactory;
 
 public class FtraceController
     implements Ftrace.Controller,
@@ -66,12 +70,12 @@ public class FtraceController
     private static final Log fine = LogFactory.fine(FtraceController.class);
 
     // ArrayList<SymbolRule>
-    private final List pltRules = new ArrayList();
     private final List symRules = new ArrayList();
+    private final List addrRules = new ArrayList();
     private final List sysRules = new ArrayList();
     private final List sigRules = new ArrayList();
 
-    // Which symbols should yield a stack trace.
+    // Which symbols and addresses should yield a stack trace.
     private HashSet tracePointStackTraceSet = new HashSet();
     private boolean stackTraceEverything = false;
 
@@ -86,16 +90,16 @@ public class FtraceController
 
     public FtraceController() { }
 
-    public void gotPltRules(List rules) {
-	fine.log("Got " + rules.size() + " PLT rules.");
-	this.pltRules.addAll(rules);
-    }
-
     public void gotSymRules(List rules) {
 	fine.log("Got " + rules.size() + " symbol rules.");
 	this.symRules.addAll(rules);
     }
 
+    public void gotAddrRules(List rules) {
+	fine.log("Got " + rules.size() + " address rules.");
+	this.addrRules.addAll(rules);
+    }
+
     public void gotSysRules(List rules) {
 	fine.log("Got " + rules.size() + " syscall rules.");
 	this.sysRules.addAll(rules);
@@ -116,15 +120,16 @@ public class FtraceController
 	    final Rule rule = (Rule)it.next();
 	    fine.log("Considering " + what + " rule `" + rule + "'.");
 	    if (!rule.apply(candidates, workingSet, stackTraceSet))
-		warning.log("Rule `" + rule + "' didn't match any " + what + ".");
+		warning.log("Rule", rule, "didn't match any", what);
 	}
 
 	// Apply the two sets.
 	Map ret = new HashMap();
 	for (Iterator it = workingSet.iterator(); it.hasNext(); ) {
-	    Object syscall = it.next();
-	    ret.put(syscall, Boolean.valueOf(stackTraceEverything
-					     || stackTraceSet.contains(syscall)));
+	    Object sysOrSig = it.next();
+	    ret.put(sysOrSig,
+		    Boolean.valueOf(stackTraceEverything
+				    || stackTraceSet.contains(sysOrSig)));
 	}
 	return ret;
     }
@@ -166,9 +171,9 @@ public class FtraceController
 	void applyTracePoint(Object tracePoint);
     }
 
-    private void applyTracingRules(final Task task, final ObjectFile objf,
-				   final List tracePoints, final List rules,
-				   RuleHandler handler)
+    private void applySymbolRules(final Task task, final ObjectFile objf,
+				  final List tracePoints,
+				  final List rules, RuleHandler handler)
 	throws lib.dwfl.ElfException
     {
 	String path = objf.getFilename().getPath();
@@ -185,21 +190,13 @@ public class FtraceController
 	final Set stackTraceSet = new HashSet();
 
 	// Loop through all the rules, and use them to build
-	// workingSet from candidates.  Candidates are initialized
-	// lazily inside the loop.
+	// workingSet from candidates.
 	for (Iterator it = rules.iterator(); it.hasNext(); ) {
 	    final SymbolRule rule = (SymbolRule)it.next();
 	    fine.log("Considering symbol rule " + rule + ".");
 
-	    // MAIN is meta-soname meaning "main executable".
-	    if ((rule.sonamePattern.pattern().equals("MAIN")
-		 && task.getProc().getExeFile().getSysRootedPath().equals(path))
-		|| (rule.sonamePattern.pattern().equals("INTERP")
-		    && isInterpOf(objf, task.getProc().getExeFile().getSysRootedPath()))
-		|| rule.sonamePattern.matcher(objf.getSoname()).matches())
-	    {
+	    if (rule.fqid.sonameMatches(task, objf))
 		rule.apply(tracePoints, workingSet, stackTraceSet);
-	    }
 	}
 
 	// Finally, apply constructed working set.
@@ -209,30 +206,106 @@ public class FtraceController
 	    handler.applyTracePoint(it.next());
     }
 
+    private void applyAddrRules(final Task task, final ObjectFile objf,
+				long bias,
+				final List rules, final Ftrace.Driver driver)
+    {
+	String path = objf.getFilename().getPath();
+	fine.log("Building checkpoint set for task", task, "and path", path);
+
+	// Skip the set if it's empty...
+	if (rules.isEmpty())
+	    return;
+
+	// Set<Long>, incrementally built working set.
+	final Set workingSet = new HashSet();
+	// Set<Long>, incrementally built set of tracepoints
+	// that should stacktrace.
+	final Set stackTraceSet = new HashSet();
+
+	// Loop through all the rules, and use them to build
+	// workingSet from candidates.
+	for (Iterator it = rules.iterator(); it.hasNext(); ) {
+	    final AddrRule rule = (AddrRule)it.next();
+	    final List candidate = new ArrayList(1);
+	    candidate.add(new Long(rule.addr));
+
+	    fine.log("Considering addr rule", rule);
+
+	    // MAIN is meta-soname meaning "main executable".
+	    if ((rule.sonamePattern.pattern().equals("MAIN")
+		 && task.getProc().getExeFile().getSysRootedPath().equals(path))
+		|| (rule.sonamePattern.pattern().equals("INTERP")
+		    && isInterpOf(objf, task.getProc().getExeFile().getSysRootedPath()))
+		|| rule.sonamePattern.matcher(objf.getSoname()).matches())
+	    {
+		rule.apply(candidate, workingSet, stackTraceSet);
+	    }
+	}
+
+	// Finally, apply constructed working set.
+	fine.log("Applying checkpoint set for ", path);
+	tracePointStackTraceSet.addAll(stackTraceSet);
+	for (Iterator it = workingSet.iterator(); it.hasNext(); ) {
+	    Long token = (Long)it.next();
+	    driver.traceAddress(task, token, bias, objf);
+	}
+    }
+
+    private List traceablesForModule(DwflModule module) {
+
+	Map symbolTable = SymbolFactory.getSymbolTable(module);
+	if (symbolTable.size() == 0)
+	    // In that case we also know there are no PLT entries,
+	    // because each PLT entry is defined on a symbol.
+	    return null;
+
+	List traceables = new ArrayList(symbolTable.values());
+	traceables.addAll(SymbolFactory.getPLTEntries(module, symbolTable));
+
+	return traceables;
+    }
+
     public void fileMapped(final Task task, ObjectFile objf,
-			   List symbols, List pltEntries,
+			   DwflModule module,
 			   final Ftrace.Driver driver) {
+
+	List traceables = traceablesForModule(module);
+	if (traceables == null)
+	    return;
+
 	try {
-	    applyTracingRules
-		(task, objf, pltEntries, pltRules,
+	    applySymbolRules
+		(task, objf, traceables, symRules,
 		 new RuleHandler() {
 		     public void applyTracePoint(Object tracePoint) {
-			 PLTEntry entry = (PLTEntry)tracePoint;
-			 driver.tracePLTEntry(task, entry);
+			 if (tracePoint instanceof PLTEntry) {
+			     PLTEntry entry = (PLTEntry)tracePoint;
+			     driver.tracePLTEntry(task, entry);
+			 } else {
+			     DwflSymbol symbol = (DwflSymbol)tracePoint;
+			     driver.traceSymbol(task, symbol);
+			 }
 		     }
 		 });
 
-	    applyTracingRules
-		(task, objf, symbols, symRules,
-		 new RuleHandler() {
-		     public void applyTracePoint(Object tracePoint) {
-			 DwflSymbol symbol = (DwflSymbol)tracePoint;
-			 driver.traceSymbol(task, symbol);
-		     }
-		 });
-	}
-	catch (lib.dwfl.ElfException ee) {
+	    ModuleElfBias eb = module.getElf();
+	    applyAddrRules(task, objf, eb.bias, addrRules, driver);
+
+	} catch (lib.dwfl.ElfException ee) {
 	    ee.printStackTrace();
 	}
     }
+
+    public void fileUnmapped(final Task task, ObjectFile objf,
+			     DwflModule module,
+			     final Ftrace.Driver driver) {
+
+	List traceables = traceablesForModule(module);
+	if (traceables == null)
+	    return;
+
+	driver.untrace(task, traceables);
+    }
+
 }
