@@ -42,20 +42,18 @@ package frysk.hpd;
 import java.io.PrintWriter;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
-import frysk.debuginfo.DebugInfoFrame;
-import frysk.debuginfo.DebugInfoStackFactory;
 import frysk.debuginfo.ObjectDeclarationSearchEngine;
-import frysk.event.Event;
-import frysk.proc.Manager;
 import frysk.proc.Task;
 import frysk.rt.BreakpointManager;
 import frysk.rt.FunctionBreakpoint;
 import frysk.rt.LineBreakpoint;
 import frysk.rt.SourceBreakpoint;
 import frysk.rt.SourceBreakpointObserver;
+import frysk.stepping.SteppingEngine;
 import frysk.value.ObjectDeclaration;
 
 class BreakpointCommand extends ParameterizedCommand {
@@ -83,7 +81,7 @@ class BreakpointCommand extends ParameterizedCommand {
 
 	public void deletedFrom(Object observable) {
 	}
-
+ 
 	public abstract void updateHit(SourceBreakpoint bpt, Task task,
                                        long address);
     }
@@ -101,6 +99,8 @@ class BreakpointCommand extends ParameterizedCommand {
 	BreakpointManager bpManager = cli.getSteppingEngine()
 		.getBreakpointManager();
 	final PrintWriter outWriter = cli.getPrintWriter();
+	final SteppingEngine ste = cli.getSteppingEngine();
+	
 	Iterator taskIter = ptset.getTasks();
 	// Map between tasks and breakpoints to enable.
 	HashMap bptMap = new HashMap();
@@ -119,20 +119,15 @@ class BreakpointCommand extends ParameterizedCommand {
 			final long address) {
                     // Output the message in an Event in order to
                     // allow all actions, fired by events currently in
-                    // the loop, to run.
-                    Manager.eventLoop.add(new Event() {
-                            public void execute() {
-                                LineBreakpoint lbpt = (LineBreakpoint) bpt;
-                                outWriter.print("Breakpoint ");
-                                outWriter.print(lbpt.getId());
-                                outWriter.print(" #");
-                                outWriter.print(lbpt.getFileName());
-                                outWriter.print("#");
-                                outWriter.print(lbpt.getLineNumber());
-                                outWriter.print(" 0x");
-                                outWriter.println(Long.toHexString(address));
-                            }
-                        });
+                    // the loop, to run.		    
+                    LineBreakpoint lbpt = (LineBreakpoint) bpt;
+                    String message = "Breakpoint " + lbpt.getId() +
+                                     " #" + lbpt.getFileName() + "#" + 
+                                     lbpt.getLineNumber() + " 0x" +
+                                     Long.toHexString(address) + "\n";
+                    ste.updateActionpointDoneEvent(message, outWriter);
+
+                    
 		}
 	    });
 	    while (taskIter.hasNext()) {
@@ -141,37 +136,51 @@ class BreakpointCommand extends ParameterizedCommand {
 	} else {
 	    while (taskIter.hasNext()) {
 		Task task = (Task) taskIter.next();
-		DebugInfoFrame frame = DebugInfoStackFactory.createDebugInfoStackTrace(task);
-		ObjectDeclarationSearchEngine declarationSearchEngine = new ObjectDeclarationSearchEngine(frame);
+		ObjectDeclarationSearchEngine declarationSearchEngine = 
+		    new ObjectDeclarationSearchEngine(task);
 		
 		if (declarationSearchEngine != null) {
-		    ObjectDeclaration die;
-		    try {
-			die = declarationSearchEngine.getObject(breakpt);
-		    } catch (RuntimeException e) {
-			// Symbol not yet visible.
-			die = null;
+		    
+		    LinkedList objects = declarationSearchEngine.getObject(breakpt);
+		    
+		    if(objects.size() > 0){
+		    Iterator iterator = objects.iterator();
+		    
+		    while (iterator.hasNext()) {			
+			ObjectDeclaration function = (ObjectDeclaration) iterator.next();
+			actionpoint = bpManager.addFunctionBreakpoint(breakpt, function);
+			actionpoint.addObserver(new CLIBreakpointObserver() {
+			    public void updateHit(final SourceBreakpoint bpt,
+				    Task task, final long address) {
+				// Output the message in an Event in order to
+				// allow all actions, fired by events currently in
+				// the loop, to run.				
+				FunctionBreakpoint fbpt = (FunctionBreakpoint) bpt;				
+				String message = "Breakpoint " + fbpt.getId() +
+				                 " " + fbpt.getName() + " 0x" + 
+				                 Long.toHexString(address) + "\n";
+				ste.updateActionpointDoneEvent(message, outWriter);
+			    }
+			});
+			bptMap.put(task, actionpoint);
 		    }
-		    actionpoint = bpManager.addFunctionBreakpoint(breakpt, die);
-		    actionpoint.addObserver(new CLIBreakpointObserver() {
-			public void updateHit(final SourceBreakpoint bpt,
-                                              Task task, final long address) {
-                            // See comment in case above.
-                            Manager.eventLoop.add(new Event() {
-                                    public void execute() {
-                                        FunctionBreakpoint fbpt
-                                            = (FunctionBreakpoint) bpt;
-                                        outWriter.print("Breakpoint ");
-                                        outWriter.print(fbpt.getId());
-                                        outWriter.print(" ");
-                                        outWriter.print(fbpt.getName());
-                                        outWriter.print(" 0x");
-                                        outWriter.println(Long.toHexString(address));
-                                    }
-                                });
-			}
-		    });
-		    bptMap.put(task, actionpoint);
+		    }else{
+		    actionpoint = bpManager.addFunctionBreakpoint(breakpt, null);
+			actionpoint.addObserver(new CLIBreakpointObserver() {
+			    public void updateHit(final SourceBreakpoint bpt,
+				    Task task, final long address) {
+				// Output the message in an Event in order to
+				// allow all actions, fired by events currently in
+				// the loop, to run.					
+				FunctionBreakpoint fbpt = (FunctionBreakpoint) bpt;
+				String message = "Breakpoint " + fbpt.getId() +
+				                 " " + fbpt.getName() + " 0x" + 
+				                 Long.toHexString(address) + "\n";
+				ste.updateActionpointDoneEvent(message, outWriter);                            
+			    }
+			});
+			bptMap.put(task, actionpoint);
+		}
 		}
 	    }
 	}
