@@ -412,7 +412,10 @@ class LinuxPPC32SyscallTable extends SyscallTable {
 	new PowerPCSyscall("timerfd", 306),
 	new PowerPCSyscall("eventfd", 307),
 	new PowerPCSyscall("sync_file_range2", 308),
-	new PowerPCSyscall("fallocate", 309)
+	new PowerPCSyscall("fallocate", 309),
+	new PowerPCSyscall("subpage_prot", 310),
+	new PowerPCSyscall("timerfd_settime", 311),
+	new PowerPCSyscall("timerfd_gettime", 312),
     };
 
     static private class SocketSubSyscall extends PowerPCSyscall {
