@@ -47,8 +47,8 @@ import java.io.InputStreamReader;
 import java.io.IOException;
 import frysk.testbed.TestLib;
 import frysk.testbed.TearDownProcess;
+import frysk.sys.PipePair;
 import frysk.config.Prefix;
-import frysk.sys.DaemonPipePair;
 
 public class TestBreakpoints
   extends TestLib
@@ -85,10 +85,9 @@ public class TestBreakpoints
     installInstructionObserver = false;
 
     // Create a process that we will communicate with through stdin/out.
-    DaemonPipePair process
-	= new DaemonPipePair(new String[] {
-				 Prefix.pkgLibFile("funit-breakpoints").getPath()
-			     });
+    PipePair process = PipePair.daemon(new String[] {
+	    Prefix.pkgLibFile("funit-breakpoints").getPath()
+	});
     TearDownProcess.add(process.pid);
     in = new BufferedReader(new InputStreamReader(process.in.getInputStream()));
     out = new DataOutputStream(process.out.getOutputStream());
