@@ -133,8 +133,6 @@ public class LinuxPtraceProc extends LiveProc {
 	if (auxv == null) {
 	    class BuildAuxv extends AuxvBuilder {
 		Auxv[] vec;
-		public void buildBuffer (byte[] auxv) {
-		}
 		public void buildDimensions (int wordSize, boolean bigEndian,
 					     int length) {
 		    vec = new Auxv[length];
@@ -197,8 +195,6 @@ public class LinuxPtraceProc extends LiveProc {
 	if (cmdLine == null) {
 	    class BuildCmdLine extends CmdLineBuilder {
 		String[] argv;
-		public void buildBuffer (byte[] buf) {
-		}
 		public void buildArgv (String[] argv) {
 		    this.argv = argv;
 		}
@@ -651,8 +647,8 @@ public class LinuxPtraceProc extends LiveProc {
 	}
 
 	public void run() {
-	    if (addition) {
-		boolean mustInstall = watchpoints.addWatchpoint(watch, task, address, length, writeOnly);
+	    if (addition) {		
+		boolean mustInstall = watchpoints.addWatchpoint(watch, task, address, length, writeOnly);		
 		if (mustInstall) {
 		    Watchpoint watchpoint;
 		    watchpoint = Watchpoint.create(address, length, writeOnly, task);
@@ -686,12 +682,21 @@ public class LinuxPtraceProc extends LiveProc {
 	fine.log(this, "requestAddWatchObserver");
 	WatchpointAction wpa = new WatchpointAction(observer, task, address, length, writeOnly, true);
 	TaskObservation to;
-	to = new TaskObservation((LinuxPtraceTask) task, observable, observer, wpa, true) {
+	to = new TaskObservation((LinuxPtraceTask) task, observable, observer, wpa, true) {	    	    
 	    public void execute() {
 		handleAddObservation(this);
 	    }
 	    public boolean needsSuspendedAction() {
 		return watchpoints.getWatchObservers(task, address, length, writeOnly) == null;
+	    }	    
+	    public void add() {
+		try {
+		    super.add();
+		} catch (Exception e) {
+		    // On any exceptions being raised in add(), call
+		    getTaskObserver().addFailed(this,e);
+		}
+		
 	    }
 	};
 	Manager.eventLoop.add(to);
