@@ -110,6 +110,19 @@ public class LinuxPtraceTask extends LiveTask {
 	((LinuxPtraceHost)proc.getHost()).putTask(tid, this);
 	((LinuxPtraceProc)proc).addTask(this);
 	newState = LinuxPtraceTaskState.mainState();
+	// See the various FIXMEs below around the isa, ISA,
+	// currentISA, getISA(), getIsaFIXME() and clearIsa(). The
+	// current design is such that the isa isn't a constant of a
+	// proc (actually task), which means we cannot remove
+	// breakpoint instructions from the fork (the breakpoint
+	// instruction is an intrinsic of the isa).  Luckily we know
+	// that the fork will have the same isa as the task it forked
+	// from, so we explicitly set it now. We cannot do the
+	// breakpoint resetting here (the LinuxPtraceTask is created,
+	// but not fully setup yet), we do that in the
+	// LinuxPtraceTaskState.StartMainTask.wantToDetach class
+	// handlers.
+	currentISA = forkingTask.currentISA;
 	if (attached != null) {
 	    TaskObservation ob = new TaskObservation(this, attachedObservers,
 						     attached, true) {
@@ -542,30 +555,30 @@ public class LinuxPtraceTask extends LiveTask {
 
 
     /**
-     * Set of Code observers.
-     *
-     * FIXME: Should be private only LinuxPtraceTaskState grubs around
-     * with this variable.
-     */
-    final TaskObservable watchObservers = new TaskObservable(this);
+     * Set of Watch observers.
+     **/
+    private final TaskObservable watchObservers = new TaskObservable(this);
+
     /**
-     * Notify all Code observers of the breakpoint. Return the number
-     * of blocking observers or -1 if no Code observer were installed
-     * on this address.
+     * Notify all Watchpoint observers of the triggered watchpoint. 
+     * Return the number of blocking observers, or 0 if nothing blocks.
      */
-    int notifyWatchpoint(long address, int length) {
-	for (Iterator i = watchObservers.iterator(); i.hasNext();) {
-	    TaskObserver.Watch observer = (TaskObserver.Watch) i.next();
-	    if (observer.updateHit(this, address, length) == Action.BLOCK) {
-		blockers.add(observer);
-	    }
+    int notifyWatchpoint(long address, int  length, boolean writeOnly) {
+	LinuxPtraceProc proc  = (LinuxPtraceProc) getProc();
+	Collection observers = proc.watchpoints.getWatchObservers(this, address, length, writeOnly);
+	
+	for (Iterator z = observers.iterator(); z.hasNext();) {
+		TaskObserver.Watch observer = (TaskObserver.Watch) z.next();
+		if (observer.updateHit(this, address, length) == Action.BLOCK) {
+		    blockers.add(observer);
+		}
 	}
 	return blockers.size();
     }
 
     /**
      * Add a TaskObserver.Watch observer
-     * (hardware only)
+     * (hardware data breakpoint only)
      */
     public void requestAddWatchObserver(TaskObserver.Watch o, long address, int length, boolean writeOnly) {
 	fine.log(this,"requestAddWatchObserver");
@@ -573,7 +586,8 @@ public class LinuxPtraceTask extends LiveTask {
     }
 
     /**
-     * Delete TaskObserver.Code for the TaskObserver pool.
+     * Delete a TaskObserver.Watch observer
+     * (hardware data breakpoint only)
      */
     public void requestDeleteWatchObserver(TaskObserver.Watch o, long address, int length, boolean writeOnly) {
 	fine.log(this, "requestDeleteWatcheObserver");
@@ -939,15 +953,40 @@ public class LinuxPtraceTask extends LiveTask {
      */
     int notifyCodeBreakpoint(long address) {
 	fine.log(this, "notifyCodeBreakpoint address", address);
-	Collection observers = ((LinuxPtraceProc)getProc()).breakpoints.getCodeObservers(address);
+	LinuxPtraceProc proc = (LinuxPtraceProc) getProc();
+	Collection observers = proc.breakpoints.getCodeObservers(address);
 	if (observers == null)
 	    return -1;
+
+	// Sanity check
+	if (steppingBreakpoint != null)
+	  throw new RuntimeException("Already breakpoint stepping: "
+				     + steppingBreakpoint);
+
+	// Reset pc, some architectures might leave the pc right after
+	// the breakpoint, but since we haven't actually executed the
+	// real instruction yet we want it to be at the actual address
+	// of the original instruction.
+	setPC(address);
+
+	// All logic for determining how and where to step the              
+	// Breakpoint is determined by Proc and                             
+	// Breakpoint.prepareStep() (called in sendContinue).               
+	Breakpoint bp = Breakpoint.create(address,proc);
+
+	// TODO: This should really move us to a new TaskState.             
+	// Currently we rely on the Task.steppingBreakpoint                 
+	// being set and the Breakpoint/Instruction having all              
+	// the state necessary.                                             
+	steppingBreakpoint = bp;
+
 	Iterator i = observers.iterator();
 	while (i.hasNext()) {
-	    TaskObserver.Code observer = (TaskObserver.Code) i.next();
-	    if (codeObservers.contains(observer))
-		if (observer.updateHit(this, address) == Action.BLOCK)
-		    blockers.add(observer);
+	    BreakpointAddresses.CodeObserver co;
+	    co = (BreakpointAddresses.CodeObserver) i.next();
+	    if (co.task.equals(this))
+		if (co.observer.updateHit(this, address) == Action.BLOCK)
+		    blockers.add(co.observer);
 	}
 	return blockers.size();
     }
@@ -991,6 +1030,7 @@ public class LinuxPtraceTask extends LiveTask {
 	}
 	return blockers.size();
     }
+    
     /**
      * Request the addition of a Instruction observer that will be
      * notified as soon as the task executes an instruction.
@@ -1009,6 +1049,10 @@ public class LinuxPtraceTask extends LiveTask {
 	fine.log(this, "requestDeleteInstructionObserver");
 	((LinuxPtraceProc)getProc()).requestDeleteInstructionObserver(this, instructionObservers, o);
     }
+    public boolean isInstructionObserverAdded (TaskObserver.Instruction o) {
+	fine.log(this, "isInstructionObserverAdded");
+	return (instructionObservers.contains(o))? true: false;
+    }    
   
     /**
      * List containing the TaskObservations that are pending addition
