@@ -691,6 +691,7 @@ abstract class LinuxPtraceTaskState extends State {
 		}
 		LinuxPtraceTaskState handleStoppedEvent(LinuxPtraceTask task,
 							Signal signal) {
+		    fine.log("handleStoppedEvent", task);
 		    if (signal == Signal.STOP || signal == Signal.TRAP) {
 			// Attempt an attached continue.
 			task.initializeAttachedState();
@@ -802,6 +803,7 @@ abstract class LinuxPtraceTaskState extends State {
 	}
 	LinuxPtraceTaskState handleStoppedEvent(LinuxPtraceTask task,
 						Signal signal) {
+	    fine.log("handleStoppedEvent", task);
 	    if (signal == Signal.STOP) {
 		Collection pendingObservations = task.pendingObservations;
 		if (pendingObservations.isEmpty()) {
@@ -932,6 +934,10 @@ abstract class LinuxPtraceTaskState extends State {
 	    // First test if this is a watchpoint event.
 	    WatchpointFunctions watchpointFunction = WatchpointFunctionFactory.
 	    	getWatchpointFunctions(task.getISA());
+
+	    if (watchpointFunction == null) {
+		return blockers;
+	    }
 	    for (int i=0; i<watchpointFunction.getWatchpointCount();  i++) {
 		// Test if a watchpoint has fired
 		if (watchpointFunction.hasWatchpointTriggered(task, i)) {
