@@ -357,7 +357,8 @@ public class TestTaskObserverCode extends TestLib
     public void symbol(String name, long value, long size,
 		       lib.dwfl.ElfSymbolType type,
 		       lib.dwfl.ElfSymbolBinding bind,
-		       lib.dwfl.ElfSymbolVisibility visibility)
+		       lib.dwfl.ElfSymbolVisibility visibility,
+		       boolean defined)
     {
       if (name.equals(this.name))
 	{
