@@ -86,7 +86,6 @@ public class Scope
     
   public Scope(DwarfDie die, TypeFactory typeFactory){
       this.die = die;
-      this.scopes = new LinkedList();
       this.typeFactory = typeFactory;
       this.sourceLocation = SourceLocationFactory.getSourceLocation(die);
   }
@@ -105,7 +104,10 @@ public class Scope
   }
   
   public LinkedList getScopes(){
-    return this.scopes;
+      if (this.scopes == null) {
+	  this.getObjectDeclarations();
+      }
+      return scopes;
   }
   
   protected DwarfDie getDie(){
@@ -114,45 +116,61 @@ public class Scope
   
   public LinkedList getVariables() {
       if (this.variables == null) {
-	  this.variables = new LinkedList();
-	  DwarfDie die = this.die.getChild();
-	  
-	  while (die != null) {
-	      
-	      if (die.getTag().equals(DwTag.VARIABLE)) {
-		  Variable variable = new Variable(die);
-		  variables.add(variable);
-	      }
-	      die = die.getSibling();
-	  }
+	  this.getObjectDeclarations();
       }
       return variables;
   }
 
+  /**
+   * Searches for variables, scopes, and object declarations
+   * Variables are variable tags
+   * scopes are scope tags
+   * objectDeclarations are either variables or NamedScopes
+   * @return
+   */
   public LinkedList getObjectDeclarations() {
       if (this.objectDeclarations == null) {
-	  this.objectDeclarations = new LinkedList();
-	  DwarfDie die = this.die.getChild();
 	  
-	  while (die != null) {
-	      
-	      try{
-		  Scope scope = ScopeFactory.theFactory.getScope(die, typeFactory);
-		  if (scope instanceof NamedScope) {
-		      this.objectDeclarations.add(scope);
-		  }
-	      } catch (IllegalArgumentException e) {
-		    if (die.getTag().equals(DwTag.VARIABLE)) {
-			Variable variable = new Variable(die);
-			objectDeclarations.add(variable);
-		    }
-		}
-	      die = die.getSibling();
+	  this.objectDeclarations = new LinkedList();
+	  this.variables = new LinkedList();
+	  this.scopes = new LinkedList();
+	  
+	  DwarfDie die = this.die.getOriginalDie();
+	  if(die != null){
+	      exploreDie(die.getChild());
 	  }
+	  die = this.die.getChild();
+	  exploreDie(die);
       }
       return objectDeclarations;
   }
 
+  private void exploreDie(DwarfDie die){
+	  while (die != null) {
+
+	      try{
+		  Scope scope = ScopeFactory.theFactory.getScope(die, typeFactory);
+		  if (scope instanceof InlinedFunction) {
+		      // skip this and trust that it will be handled by
+		      // the virtual frame corresponding to this inlining.
+		  }else{
+		      scopes.add(scope);
+		  }
+		  if (scope instanceof NamedScope) {
+		      this.objectDeclarations.add(scope);
+		  }
+	      } catch (IllegalArgumentException e) {
+
+		    if (die.getTag().equals(DwTag.VARIABLE)) {
+			Variable variable = new Variable(die); 
+			objectDeclarations.add(variable);
+			variables.add(variable);
+		    }		    
+	      }
+	      die = die.getSibling();
+	  }
+  }
+  
   public SourceLocation getSourceLocation(){
       return this.sourceLocation;
   }
@@ -195,6 +213,7 @@ public class Scope
   }
   
   public ObjectDeclaration getDeclaredObjectByName(String name){
+      
       ObjectDeclaration objectDeclaration = null;
       
       Iterator iterator = this.getObjectDeclarations().iterator();
@@ -219,12 +238,38 @@ public class Scope
       return null;
   }
   
-  public void toPrint(DebugInfoFrame frame, PrintWriter writer, String indentString){
+  /**
+   * Searches child scopes for the given name
+   * @param name
+   * @return
+   */
+  public ObjectDeclaration getDeclaredObjectByNameRecursive(String name){
+      
+      ObjectDeclaration objectDeclaration = this.getDeclaredObjectByName(name);
+      
+      if(objectDeclaration != null){
+	  return objectDeclaration;
+      }
+      
+      Iterator iterator = this.getScopes().iterator();
+      while (iterator.hasNext()) {
+	Scope scope = (Scope) iterator.next();
+	objectDeclaration = scope.getDeclaredObjectByNameRecursive(name);
+	
+	if(objectDeclaration != null){
+	    return objectDeclaration;
+	}
+      }
+      
+      
+      return null;
+  }
   
+  public void toPrint(DebugInfoFrame frame, PrintWriter writer, String indentString){
     Iterator iterator = this.getVariables().iterator();
     while(iterator.hasNext()){
 	Variable variable = (Variable) iterator.next();
-	writer.println();
+	writer.println(); 
 	writer.print(indentString + " ");
 	variable.toPrint(writer, frame);
 	writer.print(" = ");
