@@ -1,7 +1,7 @@
 // This file is part of the program FRYSK.
 //
+// Copyright 2007, 2008, Red Hat Inc.
 // Copyright 2007 Oracle Corporation.
-// Copyright 2007, Red Hat Inc.
 //
 // FRYSK is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ import frysk.rsl.LogFactory;
 
 import lib.dwfl.DwarfDie;
 import lib.dwfl.Dwfl;
-import lib.dwfl.DwflDieBias;
+import lib.dwfl.DwflDie;
 import lib.dwfl.DwflModule;
 import lib.dwfl.SymbolBuilder;
 
@@ -69,6 +69,7 @@ import lib.dwfl.SymbolBuilder;
 public class SymbolFactory
 {
     private static final Log fine = LogFactory.fine(SymbolFactory.class);
+    private static final Log finest = LogFactory.finest(SymbolFactory.class);
     private static final Log warning = LogFactory.warning(SymbolFactory.class);
 
     /**
@@ -93,13 +94,16 @@ public class SymbolFactory
 	    public void symbol(String name, long value, long size,
 			       lib.dwfl.ElfSymbolType type,
 			       lib.dwfl.ElfSymbolBinding bind,
-			       lib.dwfl.ElfSymbolVisibility visibility)
+			       lib.dwfl.ElfSymbolVisibility visibility,
+			       boolean defined)
 	    {
 		if (symbol != null)
 		    warning.log("Symbol", name, "reported on address", value,
-				"where symbol was already reported:", symbol.getName());
+				"where symbol was already reported:",
+				symbol.getName());
 		else if (name != null)
-		    symbol = new DwflSymbol (value, size, name, type, null, module);
+		    symbol = new DwflSymbol (value, size, name, type, null,
+					     module, defined);
 	    }
 	}
 	Builder builder = new Builder();
@@ -114,8 +118,8 @@ public class SymbolFactory
     private static Map getPublicTable(final DwflModule module) {
 	final Map dwSymbols = new HashMap();
 	for (Iterator it = module.getPubNames().iterator(); it.hasNext(); ) {
-	    DwflDieBias dieBias = (DwflDieBias)it.next();
-	    dwSymbols.put(dieBias.die.getName(), dieBias);
+	    DwflDie dieBias = (DwflDie)it.next();
+	    dwSymbols.put(dieBias.getName(), dieBias);
 	}
 	return dwSymbols;
     }
@@ -129,40 +133,43 @@ public class SymbolFactory
 		public void symbol(String name, long value, long size,
 				   lib.dwfl.ElfSymbolType type,
 				   lib.dwfl.ElfSymbolBinding bind,
-				   lib.dwfl.ElfSymbolVisibility visibility)
+				   lib.dwfl.ElfSymbolVisibility visibility,
+				   boolean defined)
 		{
-		    DwflDieBias dieBias = publicTable == null ? null
-			: (DwflDieBias)publicTable.get(name);
+		    DwflDie dieBias = publicTable == null ? null
+			: (DwflDie)publicTable.get(name);
 		    int index;
 		    if ((index = name.indexOf('@')) != -1)
 			name = name.substring(0, index);
 		    DwflSymbol sym
 			= new DwflSymbol(value, size, name, type,
-					 dieBias, module);
+					 dieBias, module, defined);
+		    finest.log("Symbol", name, "value", value,
+			       "type", type, "die", dieBias);
 		    table.put(name, sym);
 		}
 	};
 	module.getSymtab(builder);
-	fine.log("Got", table.size(), "symbols after sweep over symtab.");
+	fine.log("Got", table.size(), "symbols.");
 
 	// This will probably not add anything, but just to make sure...
 	for (Iterator it = publicTable.entrySet().iterator(); it.hasNext(); ) {
 	    Map.Entry entry = (Map.Entry)it.next();
 	    String name = (String)entry.getKey();
 	    if (!table.containsKey(name)) {
-		DwflDieBias dieBias = (DwflDieBias)entry.getValue();
-		DwarfDie die = dieBias.die;
+		DwflDie dieBias = (DwflDie)entry.getValue();
+		DwarfDie die = dieBias;
 		ArrayList entries = die.getEntryBreakpoints();
 		if (entries != null) {
 		    long addr = ((Long)entries.get(0)).longValue();
 		    long size = die.getHighPC() - die.getLowPC();
 		    lib.dwfl.ElfSymbolType type = null; // XXX fixme
 		    table.put(name, new DwflSymbol(addr, size, die.getName(),
-						   type, dieBias, module));
+						   type, dieBias, module,
+						   addr != 0));
 		}
 	    }
 	}
-	fine.log("Got", table.size(), "symbols after sweep over debuginfo.");
 
 	return table;
     }
@@ -198,7 +205,8 @@ public class SymbolFactory
 		public void symbol(String name, long value, long size,
 				   lib.dwfl.ElfSymbolType type,
 				   lib.dwfl.ElfSymbolBinding bind,
-				   lib.dwfl.ElfSymbolVisibility visibility)
+				   lib.dwfl.ElfSymbolVisibility visibility,
+				   boolean defined)
 		{
 		    DwflSymbol ref = (DwflSymbol)symtab.get(name);
 		    PLTEntry sym = new PLTEntry(value, ref);
@@ -225,7 +233,8 @@ public class SymbolFactory
 		public void symbol(String name, long value, long size,
 				   lib.dwfl.ElfSymbolType type,
 				   lib.dwfl.ElfSymbolBinding bind,
-				   lib.dwfl.ElfSymbolVisibility visibility)
+				   lib.dwfl.ElfSymbolVisibility visibility,
+				   boolean defined)
 		{
 		    addrs.add(new Long(value));
 		}
