@@ -868,6 +868,166 @@ public abstract class RegsCase extends TestLib {
 	.put(PPC64Registers.FPR31, // 0x5ee6e7418fe61e98
              new byte[] { 0x5e,(byte)0xe6,(byte)0xe7,0x41,
                           (byte)0x8f,(byte)0xe6,0x1e,(byte)0x98 })
+        	.put(PPC64Registers.VR0, // 0x44be6c17f1b7a38cfd16c678bd309d01
+	     new byte[] { 0x44,(byte)0xbe,0x6c,0x17,
+			  (byte)0xf1,(byte)0xb7,(byte)0xa3,(byte)0x8c,
+			  (byte)0xfd,0x16,(byte)0xc6,0x78,
+			  (byte)0xbd,0x30,(byte)0x9d,0x1 })
+	.put(PPC64Registers.VR1, // 0x4b8eacb677c1b42990652f9565244b3c
+	     new byte[] { 0x4b,(byte)0x8e,(byte)0xac,(byte)0xb6,
+			  0x77,(byte)0xc1,(byte)0xb4,0x29,
+			  (byte)0x90,0x65,0x2f,(byte)0x95,
+			  0x65,0x24,0x4b,0x3c })
+	.put(PPC64Registers.VR2, // 0x7696c4b4a91b0758114622c33bd5fbaa
+	     new byte[] { 0x76,(byte)0x96,(byte)0xc4,(byte)0xb4,
+			  (byte)0xa9,0x1b,0x7,0x58,
+			  0x11,0x46,0x22,(byte)0xc3,
+			  0x3b,(byte)0xd5,(byte)0xfb,(byte)0xaa })
+	.put(PPC64Registers.VR3, // 0x45a67a61b2ab6d7e51d42597b4582196
+	     new byte[] { 0x45,(byte)0xa6,0x7a,0x61,
+			  (byte)0xb2,(byte)0xab,0x6d,0x7e,
+			  0x51,(byte)0xd4,0x25,(byte)0x97,
+			  (byte)0xb4,0x58,0x21,(byte)0x96 })
+	.put(PPC64Registers.VR4, // 0x58fc57e626059d0facdf5aa4b0d61f65
+	     new byte[] { 0x58,(byte)0xfc,0x57,(byte)0xe6,
+			  0x26,0x5,(byte)0x9d,0xf,
+			  (byte)0xac,(byte)0xdf,0x5a,(byte)0xa4,
+			  (byte)0xb0,(byte)0xd6,0x1f,0x65 })
+	.put(PPC64Registers.VR5, // 0xccea5f417e175fa0307ad03de0a7746a
+	     new byte[] { (byte)0xcc,(byte)0xea,0x5f,0x41,
+			  0x7e,0x17,0x5f,(byte)0xa0,
+			  0x30,0x7a,(byte)0xd0,0x3d,
+			  (byte)0xe0,(byte)0xa7,0x74,0x6a })
+	.put(PPC64Registers.VR6, // 0x98b48dbbd61358bf24d173da255dc92
+	     new byte[] { 0x9,(byte)0x8b,0x48,(byte)0xdb,
+			  (byte)0xbd,0x61,0x35,(byte)0x8b,
+			  (byte)0xf2,0x4d,0x17,0x3d,
+			  (byte)0xa2,0x55,(byte)0xdc,(byte)0x92 })
+	.put(PPC64Registers.VR7, // 0xfe4405a9d77354f09a0d716f95a5d414
+	     new byte[] { (byte)0xfe,0x44,0x5,(byte)0xa9,
+			  (byte)0xd7,0x73,0x54,(byte)0xf0,
+			  (byte)0x9a,0xd,0x71,0x6f,
+			  (byte)0x95,(byte)0xa5,(byte)0xd4,0x14 })
+	.put(PPC64Registers.VR8, // 0xea387d2fc70f557bc829a16ed05fffcb
+	     new byte[] { (byte)0xea,0x38,0x7d,0x2f,
+			  (byte)0xc7,0xf,0x55,0x7b,
+			  (byte)0xc8,0x29,(byte)0xa1,0x6e,
+			  (byte)0xd0,0x5f,(byte)0xff,(byte)0xcb })
+	.put(PPC64Registers.VR9, // 0x4a148db5d37938f316475f6a5987902b
+	     new byte[] { 0x4a,0x14,(byte)0x8d,(byte)0xb5,
+			  (byte)0xd3,0x79,0x38,(byte)0xf3,
+			  0x16,0x47,0x5f,0x6a,
+			  0x59,(byte)0x87,(byte)0x90,0x2b })
+	.put(PPC64Registers.VR10, // 0xe21f644b9212debe96fa30656aadf11c
+	     new byte[] { (byte)0xe2,0x1f,0x64,0x4b,
+			  (byte)0x92,0x12,(byte)0xde,(byte)0xbe,
+			  (byte)0x96,(byte)0xfa,0x30,0x65,
+			  0x6a,(byte)0xad,(byte)0xf1,0x1c })
+	.put(PPC64Registers.VR11, // 0x463d137bf4085c18677c0d0871339086
+	     new byte[] { 0x46,0x3d,0x13,0x7b,
+			  (byte)0xf4,0x8,0x5c,0x18,
+			  0x67,0x7c,0xd,0x8,
+			  0x71,0x33,(byte)0x90,(byte)0x86 })
+	.put(PPC64Registers.VR12, // 0xea0b393faeecfde76286aff0285b4b1d
+	     new byte[] { (byte)0xea,0xb,0x39,0x3f,
+			  (byte)0xae,(byte)0xec,(byte)0xfd,(byte)0xe7,
+			  0x62,(byte)0x86,(byte)0xaf,(byte)0xf0,
+			  0x28,0x5b,0x4b,0x1d })
+	.put(PPC64Registers.VR13, // 0x8d0248447bcea6b7bff23edc456d26ca
+	     new byte[] { (byte)0x8d,0x2,0x48,0x44,
+			  0x7b,(byte)0xce,(byte)0xa6,(byte)0xb7,
+			  (byte)0xbf,(byte)0xf2,0x3e,(byte)0xdc,
+			  0x45,0x6d,0x26,(byte)0xca })
+	.put(PPC64Registers.VR14, // 0xb18799b9d5e3a6ff146df3c01257fc40
+	     new byte[] { (byte)0xb1,(byte)0x87,(byte)0x99,(byte)0xb9,
+			  (byte)0xd5,(byte)0xe3,(byte)0xa6,(byte)0xff,
+			  0x14,0x6d,(byte)0xf3,(byte)0xc0,
+			  0x12,0x57,(byte)0xfc,0x40 })
+	.put(PPC64Registers.VR15, // 0x3797881ded87e87a1e2336fb8fea1f30
+	     new byte[] { 0x37,(byte)0x97,(byte)0x88,0x1d,
+			  (byte)0xed,(byte)0x87,(byte)0xe8,0x7a,
+			  0x1e,0x23,0x36,(byte)0xfb,
+			  (byte)0x8f,(byte)0xea,0x1f,0x30 })
+	.put(PPC64Registers.VR16, // 0xfb896ec237ed9ed15ee77f2ae5f526d
+	     new byte[] { 0xf,(byte)0xb8,(byte)0x96,(byte)0xec,
+			  0x23,0x7e,(byte)0xd9,(byte)0xed,
+			  0x15,(byte)0xee,0x77,(byte)0xf2,
+			  (byte)0xae,0x5f,0x52,0x6d })
+	.put(PPC64Registers.VR17, // 0x521681e7987629fd3bbf188b1b79cfd2
+	     new byte[] { 0x52,0x16,(byte)0x81,(byte)0xe7,
+			  (byte)0x98,0x76,0x29,(byte)0xfd,
+			  0x3b,(byte)0xbf,0x18,(byte)0x8b,
+			  0x1b,0x79,(byte)0xcf,(byte)0xd2 })
+	.put(PPC64Registers.VR18, // 0x5bc0ea0e9657f1d8f766a875232164d
+	     new byte[] { 0x5,(byte)0xbc,0xe,(byte)0xa0,
+			  (byte)0xe9,0x65,0x7f,0x1d,
+			  (byte)0x8f,0x76,0x6a,(byte)0x87,
+			  0x52,0x32,0x16,0x4d })
+	.put(PPC64Registers.VR19, // 0x214c3b64a0a95653126bb7a400fd6c3
+	     new byte[] { 0x2,0x14,(byte)0xc3,(byte)0xb6,
+			  0x4a,0xa,(byte)0x95,0x65,
+			  0x31,0x26,(byte)0xbb,0x7a,
+			  0x40,0xf,(byte)0xd6,(byte)0xc3 })
+	.put(PPC64Registers.VR20, // 0x954e02b26679024890485b20e23f9171
+	     new byte[] { (byte)0x95,0x4e,0x2,(byte)0xb2,
+			  0x66,0x79,0x2,0x48,
+			  (byte)0x90,0x48,0x5b,0x20,
+			  (byte)0xe2,0x3f,(byte)0x91,0x71 })
+	.put(PPC64Registers.VR21, // 0x1226fc3704346199290bb58af16deb1d
+	     new byte[] { 0x12,0x26,(byte)0xfc,0x37,
+			  0x4,0x34,0x61,(byte)0x99,
+			  0x29,0xb,(byte)0xb5,(byte)0x8a,
+			  (byte)0xf1,0x6d,(byte)0xeb,0x1d })
+	.put(PPC64Registers.VR22, // 0xa0ef40317f5b800cc97f362c3c9a24a0
+	     new byte[] { (byte)0xa0,(byte)0xef,0x40,0x31,
+			  0x7f,0x5b,(byte)0x80,0xc,
+			  (byte)0xc9,0x7f,0x36,0x2c,
+			  0x3c,(byte)0x9a,0x24,(byte)0xa0 })
+	.put(PPC64Registers.VR23, // 0xbf06116762655604be9ed8790e30d652
+	     new byte[] { (byte)0xbf,0x6,0x11,0x67,
+			  0x62,0x65,0x56,0x4,
+			  (byte)0xbe,(byte)0x9e,(byte)0xd8,0x79,
+			  0xe,0x30,(byte)0xd6,0x52 })
+	.put(PPC64Registers.VR24, // 0x1f6182f56994c80c34a2505c7ee93f08
+	     new byte[] { 0x1f,0x61,(byte)0x82,(byte)0xf5,
+			  0x69,(byte)0x94,(byte)0xc8,0xc,
+			  0x34,(byte)0xa2,0x50,0x5c,
+			  0x7e,(byte)0xe9,0x3f,0x8 })
+	.put(PPC64Registers.VR25, // 0x68225bcb834745faeee567033c6f750f
+	     new byte[] { 0x68,0x22,0x5b,(byte)0xcb,
+			  (byte)0x83,0x47,0x45,(byte)0xfa,
+			  (byte)0xee,(byte)0xe5,0x67,0x3,
+			  0x3c,0x6f,0x75,0xf })
+	.put(PPC64Registers.VR26, // 0x6596dcddd93ddbf55492cf8184147889
+	     new byte[] { 0x65,(byte)0x96,(byte)0xdc,(byte)0xdd,
+			  (byte)0xd9,0x3d,(byte)0xdb,(byte)0xf5,
+			  0x54,(byte)0x92,(byte)0xcf,(byte)0x81,
+			  (byte)0x84,0x14,0x78,(byte)0x89 })
+	.put(PPC64Registers.VR27, // 0xef4dd08222103314c388b9fd0c466d4c
+	     new byte[] { (byte)0xef,0x4d,(byte)0xd0,(byte)0x82,
+			  0x22,0x10,0x33,0x14,
+			  (byte)0xc3,(byte)0x88,(byte)0xb9,(byte)0xfd,
+			  0xc,0x46,0x6d,0x4c })
+	.put(PPC64Registers.VR28, // 0xb67426e81b4bc303da89a6b848eb7870
+	     new byte[] { (byte)0xb6,0x74,0x26,(byte)0xe8,
+			  0x1b,0x4b,(byte)0xc3,0x3,
+			  (byte)0xda,(byte)0x89,(byte)0xa6,(byte)0xb8,
+			  0x48,(byte)0xeb,0x78,0x70 })
+	.put(PPC64Registers.VR29, // 0x195d48ca281de73c7d559ad4a6746d70
+	     new byte[] { 0x19,0x5d,0x48,(byte)0xca,
+			  0x28,0x1d,(byte)0xe7,0x3c,
+			  0x7d,0x55,(byte)0x9a,(byte)0xd4,
+			  (byte)0xa6,0x74,0x6d,0x70 })
+	.put(PPC64Registers.VR30, // 0xe91cb114b1caf3e4e9f95bfee49b8948
+	     new byte[] { (byte)0xe9,0x1c,(byte)0xb1,0x14,
+			  (byte)0xb1,(byte)0xca,(byte)0xf3,(byte)0xe4,
+			  (byte)0xe9,(byte)0xf9,0x5b,(byte)0xfe,
+			  (byte)0xe4,(byte)0x9b,(byte)0x89,0x48 })
+	.put(PPC64Registers.VR31, // 0x7ea2a6afa222b34fec61791416397ac
+	     new byte[] { 0x7,(byte)0xea,0x2a,0x6a,
+			  (byte)0xfa,0x22,0x2b,0x34,
+			  (byte)0xfe,(byte)0xc6,0x17,(byte)0x91,
+			  0x41,0x63,(byte)0x97,(byte)0xac })
 	;
     private final ISAMap isaValues = new ISAMap("RegsCase")
 	.put(ISA.IA32, IA32)
