@@ -47,17 +47,18 @@ import java.io.File;
  */
 
 public final class Fork {
-    static final int NO_TRACE = 0;
-    static final int UTRACE = 1;
-    static final int PTRACE = 2;
-    private static native ProcessIdentifier spawn(File exe,
-						  String in, String out,
-						  String err,
-						  String[] args, 
-						  long environ, int trace);
-    private static ProcessIdentifier spawn(String[] args, int trace) {
-	return spawn(new File(args[0]), null, null, null, args, 0, trace);
-    }
+    private static native int spawn(String exe,
+				    String in, String out, String err,
+				    String[] args, String[] environ);
+    private static native int ptrace(String exe,
+				     String in, String out, String err,
+				     String[] args, String[] environ);
+    private static native int utrace(String exe,
+				     String in, String out, String err,
+				     String[] args, String[] environ);
+    private static native int daemon(String exe,
+				     String in, String out, String err,
+				     String[] args, String[] environ);
 
     /**
      * Create a child process running EXE with arguments ARGS[0..].
@@ -67,7 +68,9 @@ public final class Fork {
     public static ProcessIdentifier exec(File exe,
 					 String in, String out,
 					 String err, String[] args) {
-	return spawn(exe, in, out, err, args, 0, NO_TRACE);
+	return ProcessIdentifierFactory.create(spawn(exe.getPath(),
+						     in, out, err,
+						     args, null));
     }
     /**
      * Create a child process running EXE with arguments ARGS[0..].
@@ -76,14 +79,18 @@ public final class Fork {
      */
     public static ProcessIdentifier exec(String in, String out,
 					 String err, String[] args) {
-	return spawn(new File(args[0]), in, out, err, args, 0, NO_TRACE);
+	return ProcessIdentifierFactory.create(spawn(args[0],
+						     in, out, err,
+						     args, null));
     }
     /**
      * Create a child process running ARGS[0] with arguments
      * ARGS[0..].
      */
     public static ProcessIdentifier exec(String[] args) {
-	return spawn(args, NO_TRACE);
+	return ProcessIdentifierFactory.create(spawn(args[0],
+						     null, null, null,
+						     args, null));
     }
 
     /**
@@ -93,19 +100,21 @@ public final class Fork {
      * Also wire up IN, OUT, and ERR.
      */
     public static ProcessIdentifier ptrace(File exe,
-					   String in, String out, 
-					   String err, String[] args, String libs) {
-	Environ environ = new Environ();
-	environ.setEnv("LD_LIBRARY_PATH", libs);
-	long env = environ.putEnviron();
-	return spawn(exe, in, out, err, args, env, PTRACE);
+					   String in, String out, String err,
+					   String[] args,
+					   String[] environ) {
+	return ProcessIdentifierFactory.create(ptrace(exe.getPath(),
+						      in, out, err,
+						      args, environ));
     }
     /**
      * Create a child process running ARGS[0] with arguments
      * ARGS[0...]; mark the process for tracing.
      */
     public static ProcessIdentifier ptrace(String[] args) {
-	return spawn(args, PTRACE);
+	return ProcessIdentifierFactory.create(ptrace(args[0],
+						      null, null, null,
+						      args, null));
     }
 
     /**
@@ -117,38 +126,38 @@ public final class Fork {
     public static ProcessIdentifier utrace(File exe,
 					   String in, String out,
 					   String err, String[] args) {
-	return spawn(exe, in, out, err, args, 0, UTRACE);
+	return ProcessIdentifierFactory.create(utrace(exe.getPath(),
+						      in, out, err,
+						      args, null));
     }
     /**
      * Create a child process running ARGS[0] with arguments
      * ARGV[0...]; mark the process for utracing.
      */
     public static ProcessIdentifier utrace(String[] args) {
-	return spawn(args, UTRACE);
+	return ProcessIdentifierFactory.create(utrace(args[0],
+						      null, null, null,
+						      args, null));
     }
 
     /**
      * Create a "daemon" process running ARGV[0] with arguments
      * ARGV[1...]; a daemon has process ID 1 as its parent.
-     *
-     * Also wire up IN, OUT, and ERR.
      */
-    public static native ProcessIdentifier daemon(File exe,
-						  String in, String out,
-						  String err, String[] argv);
-    /**
-     * Create a "daemon" process running ARGV[0] with arguments
-     * ARGV[1...]; a daemon has process ID 1 as its parent.
-     */
-    public static ProcessIdentifier daemon(String in, String out, String err,
+    public static ProcessIdentifier daemon(File exe,
+					   String in, String out, String err,
 					   String[] argv) {
-	return daemon(new File(argv[0]), in, out, err, argv);
+	return ProcessIdentifierFactory.create(daemon(exe.getPath(),
+						      in, out, err,
+						      argv, null));
     }
     /**
      * Create a "daemon" process running ARGV[0] with arguments
      * ARGV[1...]; a daemon has process ID 1 as its parent.
      */
     public static ProcessIdentifier daemon(String[] argv) {
-	return daemon(new File(argv[0]), null, null, null, argv);
+	return ProcessIdentifierFactory.create(daemon(argv[0],
+						      null, null, null,
+						      argv, null));
     }
 }
