@@ -40,7 +40,6 @@
 package frysk.sys;
 
 import frysk.junit.TestCase;
-import frysk.testbed.Tee;
 import frysk.rsl.Log;
 import frysk.config.Prefix;
 
@@ -98,32 +97,12 @@ public class TestPipePair extends TestCase {
     /**
      * Test a daemon Pipe pair.
      */
-    public void testDaemonTee ()
-    {
-	pipe = new DaemonPipePair (tee);
+    public void testDaemonTee() {
+	pipe = PipePair.daemon(tee);
 	verifyIO ();
     }
-    public void testChildTee ()
-    {
-	pipe = new ChildPipePair (tee);
-	verifyIO ();
-    }
-
-    /**
-     * Test a daemon assembly file.
-     */
-    public void testDaemonExecute ()
-    {
-	pipe = new DaemonPipePair (new Tee ());
-	verifyIO ();
-    }
-
-    /**
-     * Test a child assembly file.
-     */
-    public void testChildExecute ()
-    {
-	pipe = new ChildPipePair (new Tee ());
+    public void testChildTee() {
+	pipe = PipePair.child(tee);
 	verifyIO ();
     }
 
@@ -143,7 +122,7 @@ public class TestPipePair extends TestCase {
 	assertTrue("SIGHUP masked",
 		   new SignalSet().getProcMask().contains(Signal.HUP));
 	fine.log("Creating funit-procmask to check the mask");
-	pipe = new DaemonPipePair(funitProcMask);
+	pipe = PipePair.daemon(funitProcMask);
 	// For a daemon, it isn't possible to capture the processes
 	// exit status; instead read the output and check for the word
 	// "absent".
@@ -162,7 +141,7 @@ public class TestPipePair extends TestCase {
 	assertTrue("SIGHUP masked",
 		   new SignalSet().getProcMask().contains(Signal.HUP));
 	fine.log("Creating funit-procmask to check the mask");
-	pipe = new ChildPipePair(funitProcMask);
+	pipe = PipePair.child(funitProcMask);
 	// Capture the child's output (look for 
 	class ExitStatus extends UnhandledWaitBuilder {
 	    ProcessIdentifier pid;
