@@ -38,7 +38,6 @@
 // exception.
 
 #include <stdio.h>
-#include <alloca.h>
 #include <errno.h>
 #include <unistd.h>
 #include <sys/ptrace.h>
@@ -50,50 +49,54 @@
 #include "java/io/File.h"
 #include "frysk/sys/Fork.h"
 #include "frysk/sys/cni/Errno.hxx"
-
+#include "frysk/sys/cni/Fork.hxx"
 #include "frysk/sys/ProcessIdentifier.h"
 #include "frysk/sys/ProcessIdentifierFactory.h"
 
-static void
-reopen (jstring file, const char *mode, FILE *stream)
-{
-  if (file == NULL)
-    return;
-  int len = JvGetStringUTFLength (file);
-  char *fileName = (char *) alloca (len + 1);
-  JvGetStringUTFRegion (file, 0, file->length (), fileName);
-  fileName[len] = '\0';
-  errno = 0;
-  ::freopen (fileName, mode, stream);
-  if (errno != 0) {
-    ::perror ("freopen");
-    ::_exit (errno);
-  }
-}
-
+/**
+ * Spawn a child, return the PID or throw the error.
+ */
 int
-spawn(java::io::File* exe, jstring in, jstring out, jstring err,
-      jstringArray args, jlong environ, jint trace)
-{
-  // Convert args into argv, argc, filename.
-  char *filename = ALLOCA_STRING(exe->getPath());
-  int argc = JvGetArrayLength (args);
-  char **argv = (char **) alloca ((argc + 1) * sizeof (void*));
-  for (int i = 0; i < argc; i++) {
-    jstring arg = elements (args)[i];
-    int len = JvGetStringUTFLength (arg);
-    argv[i] = (char *) alloca (len + 1);
-    JvGetStringUTFRegion (arg, 0, arg->length (), argv[i]);
-    argv[i][len] = '\0';
+spawn(tracing trace, redirect& redirection, exec& execute) {
+  if (trace == DAEMON) {
+    // Do a vfork(), fork(), exec() which lets the top level process
+    // capture the middle level fork()'s return value in a volatile.
+    volatile int pid = -1;
+    register int v;
+    errno = 0;
+    v = vfork ();
+    switch (v) {
+    case 0:
+      // This is executed by the child with the parent blocked, the
+      // final process id ends up in PID.
+      pid = ::spawn(CHILD, redirection, execute);
+      _exit (0);
+    case -1:
+      // This is executed after a vfork barfs.
+      throwErrno(errno, "vfork");
+    default:
+      // This is executed after the child has set PID with a FORK and
+      // then exited (which helps guarentee that the waitpid, below,
+      // doesn't block.
+      if (pid < 0) {
+	throwErrno(errno, "vfork/fork");
+      }
+      // Consume the middle players wait.
+      int status;
+      errno = 0;
+      if (waitpid(v, &status, 0) < 0) {
+	throwErrno(errno, "waitpid");
+      }
+      return pid;
+    }
   }
-  argv[argc] = 0;
 
   // Fork/exec
   errno = 0;
   pid_t pid = fork ();
   switch (pid) {
   case -1: // Fork failed.
-    throwErrno (errno, "fork");
+    throwErrno(errno, "fork");
   default: // Parent
     return pid;
   case 0: // Child
@@ -102,75 +105,97 @@ spawn(java::io::File* exe, jstring in, jstring out, jstring err,
     sigfillset(&mask);
     ::sigprocmask(SIG_UNBLOCK, &mask, NULL);
     // Redirect stdio.
-    reopen (in, "r", stdin);
-    reopen (out, "w", stdout);
-    reopen (err, "w", stderr);
+    redirection.reopen();
     switch (trace) {
-    case frysk::sys::Fork::PTRACE:
+    case PTRACE:
       errno = 0;
-      ::ptrace ((enum __ptrace_request) PTRACE_TRACEME, 0, 0, 0);
+      ::ptrace((enum __ptrace_request) PTRACE_TRACEME, 0, 0, 0);
       if (errno != 0) {
 	::perror ("ptrace.traceme");
-	::_exit (errno);
+	::_exit(errno);
       }
       break;
-    case frysk::sys::Fork::UTRACE:
+    case UTRACE:
       fprintf(stderr, "\n\n>>>>> in spawn(...utrace)\n\n");
       break;
-    case frysk::sys::Fork::NO_TRACE:
+    case CHILD:
+      break;
+    case DAEMON:
       break;
     }
-     if (environ != 0) {
-	::execve (filename, argv, (char **)environ);
-       }
-     else
-      ::execv (filename, argv);
-    // This should not happen.
-    ::perror ("execvp");
-    ::_exit (errno);
+    execute.execute();
+    ::_exit(errno);
   }
 }
 
-frysk::sys::ProcessIdentifier*
-frysk::sys::Fork::spawn(java::io::File* exe,
+class redirect_stdio : public redirect {
+private:
+  void reopen(const char* file, const char* mode, FILE *stream) {
+    if (file == NULL)
+      return;
+    errno = 0;
+    ::freopen(file, mode, stream);
+    if (errno != 0) {
+      // Should not happen!
+      ::perror("freopen");
+      ::_exit(errno);
+    }
+  }
+  char* in;
+  char* out;
+  char* err;
+public:
+  redirect_stdio(jstring in, jstring out, jstring err) {
+    this->in = MALLOC_STRING(in);
+    this->out = MALLOC_STRING(out);
+    this->err = MALLOC_STRING(err);
+  }
+  void reopen() {
+    reopen(in, "r", stdin);
+    reopen(out, "w", stdout);
+    reopen(err, "w", stderr);
+  }
+  ~redirect_stdio() {
+    JvFree(in);
+    JvFree(out);
+    JvFree(err);
+  }
+};
+
+/**
+ * Convert convert to native and then spawn.
+ */
+static int
+spawn(jstring exe, jstring in, jstring out, jstring err,
+      jstringArray args, jstringArray environ, tracing trace) {
+  redirect_stdio io = redirect_stdio(in, out, err);
+  exec_program program = exec_program(exe, args, environ);
+  return ::spawn(trace, io, program);
+}
+
+jint
+frysk::sys::Fork::spawn(jstring exe,
 			jstring in, jstring out, jstring err,
-			jstringArray args, jlong environ, jint trace) {
-  int pid = ::spawn(exe, in, out, err, args, environ, trace);
-  return frysk::sys::ProcessIdentifierFactory::create(pid);
+			jstringArray args, jstringArray environ) {
+  return ::spawn(exe, in, out, err, args, environ, CHILD);
 }
 
-frysk::sys::ProcessIdentifier*
-frysk::sys::Fork::daemon (java::io::File* exe, jstring in, jstring out,
-			  jstring err, jstringArray args)
-{
-  volatile int pid = -1;
-  register int v;
-  errno = 0;
-  v = vfork ();
+jint
+frysk::sys::Fork::ptrace(jstring exe,
+			jstring in, jstring out, jstring err,
+			jstringArray args, jstringArray environ) {
+  return ::spawn(exe, in, out, err, args, environ, PTRACE);
+}
 
-  // This is executed by the child with the parent blocked, the final
-  // process id ends up in PID.
+jint
+frysk::sys::Fork::utrace(jstring exe,
+			jstring in, jstring out, jstring err,
+			jstringArray args, jstringArray environ) {
+  return ::spawn(exe, in, out, err, args, environ, UTRACE);
+}
 
-  if (v == 0) {
-    pid = ::spawn(exe, in, out, err, args, 0, frysk::sys::Fork::NO_TRACE);
-    _exit (0);
-  }
-
-  // This is executed after the child has exited (which helps
-  // guarentee that the waitpid, below, doesn't block.
-
-  if (v < 0)
-    throwErrno (errno, "vfork");
-  if (pid < 0)
-    throwErrno (errno, "fork");
-  
-  // Consume the middle players wait.
-  int status;
-  errno = 0;
-  if (waitpid (v, &status, 0) < 0)
-    throwErrno (errno, "waitpid", "process %d", v);
-
-  // printf ("v %d pid %d\n", v, pid);
-
-  return frysk::sys::ProcessIdentifierFactory::create(pid);
+jint
+frysk::sys::Fork::daemon (jstring exe, jstring in, jstring out, jstring err,
+			  jstringArray args, jstringArray environ) {
+  return ::spawn(exe, in, out, err, args, environ, DAEMON);
 }
