@@ -47,6 +47,12 @@ package frysk.testbed;
  */
 
 public class LocalMemory {
+    /**
+     * Return the basename of the shared library or executable that
+     * contains the LocalMemory.
+     */
+    public static native String getModuleName();
+
     /**
      * Returns the address of a bunch of data.
      */
@@ -57,6 +63,11 @@ public class LocalMemory {
      */
     public static native byte[] getDataBytes();
 
+    /**
+     * Returns the name of the code function.
+     */
+    public static native String getCodeName();
+
     /**
      * Returns the address of a function.
      */
