@@ -1,6 +1,6 @@
 // This file is part of the program FRYSK.
 //
-// Copyright 2005, 2006, 2007 Red Hat Inc.
+// Copyright 2005, 2006, 2007, 2008 Red Hat Inc.
 //
 // FRYSK is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by
@@ -46,6 +46,8 @@
 #include "frysk/testbed/LocalMemory.h"
 #include "frysk/testbed/LocalMemory$StackBuilder.h"
 
+using namespace frysk::testbed;
+
 static jbyteArray
 getBytes(void *addr, size_t length) {
   jbyteArray bytes = JvNewByteArray(length);
@@ -61,12 +63,12 @@ struct m {
 } memory = { 43, 45, 42, 44 };
 
 jlong
-frysk::testbed::LocalMemory::getDataAddr() {
+LocalMemory::getDataAddr() {
   return (jlong) &memory;
 }
 
 jbyteArray
-frysk::testbed::LocalMemory::getDataBytes() {
+LocalMemory::getDataBytes() {
   return getBytes(&memory, sizeof(memory));
 }
 
@@ -74,36 +76,57 @@ frysk::testbed::LocalMemory::getDataBytes() {
  * Function used by getCode*(), must be on a single line for __LINE__
  * to work correctly.
  */
-jint frysk::testbed::LocalMemory::getCodeLine () { return __LINE__; }
+extern "C" {
+  static jint codeLine() { return __LINE__; }
+}
 
 jstring
-frysk::testbed::LocalMemory::getCodeFile() {
+LocalMemory::getCodeName() {
+  return JvNewStringUTF("codeLine");
+}
+
+jint
+LocalMemory::getCodeLine() {
+  return codeLine();
+}
+
+jstring
+LocalMemory::getCodeFile() {
   return JvNewStringUTF (__FILE__);
 }
 
 static void*
 codeAddr() {
 #ifdef __powerpc64__
-  return *((void**) frysk::testbed::LocalMemory::getCodeLine);
+  return *((void**) codeLine);
 #else
-  return (void*)&frysk::testbed::LocalMemory::getCodeLine;
+  return (void*)&codeLine;
 #endif
 }
+
 jlong
-frysk::testbed::LocalMemory::getCodeAddr() {
+LocalMemory::getCodeAddr() {
   return (jlong)codeAddr();
 }
 
 jbyteArray
-frysk::testbed::LocalMemory::getCodeBytes() {
+LocalMemory::getCodeBytes() {
   return getBytes(codeAddr(), sizeof(memory));
 }
 
 void
-frysk::testbed::LocalMemory::constructStack(frysk::testbed::LocalMemory$StackBuilder* builder) {
+LocalMemory::constructStack(LocalMemory$StackBuilder* builder) {
   // Copy known data onto the stack.
   uint8_t addr[sizeof(memory)];
   memcpy(addr, &memory, sizeof(memory));
   jbyteArray bytes = getBytes(addr, sizeof(memory));
   builder->stack((jlong)addr, bytes);
 }
+
+jstring
+LocalMemory::getModuleName() {
+  // XXX: Should account for build-tree TestRunner vs install tree
+  // funit, but not important as this CNI implementation will shortly
+  // be deleted.
+  return JvNewStringUTF("TestRunner");
+}
