@@ -1,6 +1,6 @@
 // This file is part of the program FRYSK.
 //
-// Copyright 2005, 2006, 2007, Red Hat Inc.
+// Copyright 2005, 2006, 2007, 2008, Red Hat Inc.
 //
 // FRYSK is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by
@@ -45,12 +45,13 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 
-abstract public class DwarfDie {
+public class DwarfDie {
 
     private long pointer;
     private DwarfDie[] scopes;
     private int scopeIndex;
-    private DwflModule module;
+    // XXX: Belongs in DwflDie.
+    DwflModule module;
 
     protected boolean manageDie = false;
   
@@ -62,7 +63,7 @@ abstract public class DwarfDie {
     protected DwflModule getModule(){
 	return module;
     }
-    
+
     protected DwarfDie getCompilationUnit(){
 	
 	if(this.getTag().equals(DwTag.COMPILE_UNIT)){
@@ -76,21 +77,28 @@ abstract public class DwarfDie {
 	return scopes[scopes.length -1];
     }
     
-    protected Dwfl getDwfl () {
-	return this.module.getParent();
-    }
-
     public long getHighPC () {
-	return get_highpc();
+	return dwarf_highpc(pointer);
     }
+    private static native long dwarf_highpc(long pointer);
 
     public long getLowPC () {
-	return get_lowpc();
+	return dwarf_lowpc(pointer);
     }
+    private static native long dwarf_lowpc(long pointer);
+
+    /**
+     * @return entry pc or low pc if this die
+     */
+    public long getEntryPc(){
+	return dwarf_entrypc(pointer);
+    }
+    private static native long dwarf_entrypc(long pointer);
 
     public String getName () {
-	return get_diename();
+	return dwarf_diename(pointer);
     }
+    private static native String dwarf_diename(long pointer);
     
     public String getProducer () {
 	return getCompilationUnit().getAttrString(DwAt.PRODUCER);
@@ -99,7 +107,7 @@ abstract public class DwarfDie {
     public File getDeclFile() {
 	File file = null;
 	try{
-	    file = new File(get_decl_file(this.getPointer()));
+	    file = new File(get_decl_file(pointer));
 	}catch (DwAttributeNotFoundException e) {
 	    if(isDefinitionOnly()){
 		file = getOriginalDie().getDeclFile();
@@ -112,7 +120,7 @@ abstract public class DwarfDie {
 	int line = -1;
 	
 	try{
-	    line = get_decl_line(this.getPointer());
+	    line = get_decl_line(pointer);
 	}catch (DwAttributeNotFoundException e) {
 	    if(isDefinitionOnly()){
 		line = getOriginalDie().getDeclLine();
@@ -122,7 +130,7 @@ abstract public class DwarfDie {
     }
 
     public int getDeclColumn() {
-	return get_decl_column(this.getPointer());
+	return get_decl_column(pointer);
     }
   
     public void setScopes(DwarfDie[] scopes) {
@@ -180,7 +188,7 @@ abstract public class DwarfDie {
 	long[] vals = new long[scopes.length];
 	long[] die_and_scope = new long[2];
 	for(int i = 0; i < scopes.length; i++)
-	    vals[i] = scopes[i].getPointer();
+	    vals[i] = scopes[i].pointer;
 
 	DwarfDie die = null;
 	long val = get_scopevar(die_and_scope, vals, variable);
@@ -203,7 +211,7 @@ abstract public class DwarfDie {
 	varNames = new ArrayList();    
 	long[] vals = new long[scopes.length];
 	for(int i = 0; i < scopes.length; i++)
-	    vals[i] = scopes[i].getPointer();
+	    vals[i] = scopes[i].pointer;
 
 	get_scopevar_names(vals, variable);
 	return varNames; 
@@ -242,7 +250,7 @@ abstract public class DwarfDie {
     public List getAddr()
     {
 	DwarfOps = new ArrayList();
-	get_addr(this.getPointer(), 0);
+	get_addr(pointer, 0);
 	return DwarfOps;
     }
 
@@ -261,22 +269,22 @@ abstract public class DwarfDie {
     }
     private DwarfDie getType(boolean followTypeDef) {
 	DwarfDie die = null;
-	long type = get_type(this.getPointer(), followTypeDef);
+	long type = get_type(pointer, followTypeDef);
 	if (type != 0)
 	    die = DwarfDieFactory.getFactory().makeDie(type, this.module);
 	return die;
     }
 
     public boolean getAttrBoolean(DwAt attr) {
-	return get_attr_boolean(this.getPointer(), attr.hashCode());
+	return get_attr_boolean(pointer, attr.hashCode());
     }
     
     public String getAttrString(DwAt attr) {
-	return get_attr_string(this.getPointer(), attr.hashCode());
+	return get_attr_string(pointer, attr.hashCode());
     }
   
     public DwTag getTag() {
-	return DwTag.valueOf(get_tag(this.getPointer()));
+	return DwTag.valueOf(get_tag(pointer));
     }
     
   
@@ -284,21 +292,21 @@ abstract public class DwarfDie {
      * @return The upper bound for this subrange die.
      */
     public int getAttrConstant(DwAt attr) {
-	return get_attr_constant(this.getPointer(), attr.hashCode());
+	return get_attr_constant(pointer, attr.hashCode());
     }
 
     /**
      * @return The offset for this die.
      */
     public long getOffset() {
-	return get_offset(this.getPointer());
+	return get_offset(pointer);
     }
 
     /**
      * @return The child for the current die.
      */
     public DwarfDie getChild() {
-	long child = get_child(this.getPointer());
+	long child = get_child(pointer);
 	DwarfDie die = null;
 	if (child != 0)
 	    die = DwarfDieFactory.getFactory().makeDie(child, this.module);
@@ -309,17 +317,13 @@ abstract public class DwarfDie {
      * @return The sibling for the current die.
      */
     public DwarfDie getSibling() {
-	long sibling = get_sibling(this.getPointer());
+	long sibling = get_sibling(pointer);
 	DwarfDie die = null;
 	if (sibling != 0)
 	    die = DwarfDieFactory.getFactory().makeDie(sibling, this.module);
 	return die;
     }
   
-    protected long getPointer() {
-	return this.pointer;
-    }
- 
     /**
      * @param pc Program Counter
      * @return DW_AT_frame_base for current die.
@@ -329,7 +333,7 @@ abstract public class DwarfDie {
       
 	DwarfOps = new ArrayList();
 	for (int i = this.scopeIndex; i < this.scopes.length; i++) {
-	    get_framebase(this.getPointer(), this.scopes[i].pointer, pc);
+	    get_framebase(pointer, this.scopes[i].pointer, pc);
 	    if (DwarfOps.size() != 0)
 		break;
 	}
@@ -343,12 +347,12 @@ abstract public class DwarfDie {
      */
     public List getFormData(long pc) {
 	DwarfOps = new ArrayList();
-	get_addr(this.getPointer(), pc);
+	get_addr(pointer, pc);
 	return DwarfOps;
     }
 
     public long getDataMemberLocation() {
-	return get_data_member_location(this.getPointer());
+	return get_data_member_location(pointer);
     }
   
     /**
@@ -360,7 +364,7 @@ abstract public class DwarfDie {
     }
   
     public boolean hasAttribute(DwAt attr){
-	return hasattr(getPointer(), attr.hashCode());
+	return hasattr(pointer, attr.hashCode());
     }
     
     public String toString() {
@@ -402,7 +406,7 @@ abstract public class DwarfDie {
      * @return die
      */
     public static DwarfDie getDeclCU(DwarfDie[] scopes, String sym) {
-	long result = get_decl_cu (scopes[0].getPointer(), sym);
+	long result = get_decl_cu (scopes[0].pointer, sym);
 	DwarfDie die = null;
 	if (result > 0) {
 	    die = DwarfDieFactory.getFactory().makeDie(result, null);
@@ -419,7 +423,7 @@ abstract public class DwarfDie {
     public DwarfDie getOriginalDie() {
 	if(this.hasAttribute(DwAt.ABSTRACT_ORIGIN) ||
 		this.hasAttribute(DwAt.SPECIFICATION)){
-	    long original_die = get_original_die(this.getPointer());
+	    long original_die = get_original_die(pointer);
 	    DwarfDie die = null;
 	    if (original_die != 0)
 		die = DwarfDieFactory.getFactory().makeDie(original_die, this.module);
@@ -444,9 +448,8 @@ abstract public class DwarfDie {
 	// try to find the definition 
 	// try using pubnames
 	LinkedList pubnames = this.getModule().getPubNames();
-	Iterator iterator = pubnames.iterator();
-	while (iterator.hasNext()) {
-	    DwarfDie die = ((DwflDieBias) iterator.next()).die;
+	for (Iterator i = pubnames.iterator(); i.hasNext(); ) {
+	    DwarfDie die = (DwarfDie) i.next();
 	    DwarfDie originalDie = die.getOriginalDie();
 	    if(originalDie != null && originalDie.getModule().getName().equals(this.getModule().getName()) &&
 		    originalDie.getOffset() == this.getOffset()){
@@ -457,29 +460,12 @@ abstract public class DwarfDie {
 	return null;
     }
 
-    /**
-     * @return entry pc or low pc if this die
-     */
-    public long getEntryPc(){
-	return get_entrypc();
-    }
-    
-    abstract public void accept(DieVisitor visitor);
-
     public native ArrayList getEntryBreakpoints();
 
     public native boolean isInlineDeclaration();
 
     public native ArrayList getInlinedInstances();
   
-    private native long get_lowpc ();
-
-    private native long get_highpc ();
-
-    protected native long get_entrypc();
-
-    private native String get_diename ();
-  
     private native String get_decl_file (long var_die);
   
     private native int get_decl_line (long var_die);
