@@ -49,7 +49,6 @@
 #include <gnu/gcj/RawData.h>
 
 #include "lib/dwfl/Dwfl.h"
-#include "lib/dwfl/DwflDieBias.h"
 #include "lib/dwfl/DwarfDie.h"
 #include "lib/dwfl/DwarfDieFactory.h"
 #include "lib/dwfl/DwflModule.h"
@@ -57,20 +56,23 @@
 #include "inua/eio/Buffer.h"
 #include "inua/eio/ByteBuffer.h"
 
+using namespace java::lang;
+
 // Suck in elf_from_remote_memory from elfutils
 
 extern "C"
 {
-    extern ::Elf *elf_from_remote_memory (GElf_Addr ehdr_vma,
-                                          GElf_Addr *loadbasep,
-                                          ssize_t (*read_memory) (void *arg,
-                                                                  void *data,
-                                                                  GElf_Addr address,
-                                                                  size_t minread,
-                                                                  size_t maxread),
-                                          void *arg);
+  extern ::Elf *elf_from_remote_memory (GElf_Addr ehdr_vma,
+					GElf_Addr *loadbasep,
+					ssize_t (*read_memory) (void *arg,
+								void *data,
+								GElf_Addr address,
+								size_t minread,
+								size_t maxread),
+					void *arg);
 }
-#define DWFL_POINTER (::Dwfl *) this->pointer
+#define DWFL_POINTER ((::Dwfl *) pointer)
+#define DWFL_CALLBACKS ((::Dwfl_Callbacks *) callbacks)
 
 static ssize_t
 read_proc_memory (void *arg, void *data, GElf_Addr address,
@@ -111,7 +113,7 @@ dwfl_frysk_proc_find_elf (Dwfl_Module *mod,
 	}
       return fd;
     }
-   else
+  else
     {
       /* Special case for in-memory ELF image.  */
       inua::eio::ByteBuffer * memory = (inua::eio::ByteBuffer *) *userdata;           
@@ -121,90 +123,71 @@ dwfl_frysk_proc_find_elf (Dwfl_Module *mod,
       return -1;
     }
 
- //abort ();
+  //abort ();
   return -1;
 }
 
-gnu::gcj::RawData*
-lib::dwfl::Dwfl::dwflBegin (jstring jsysroot, jint pid)
-{
-  int len = jsysroot->length ();
-  // jsize len = JvGetStringUTFLength(jsysroot);
-  char sysroot[len + 1]; 
-  JvGetStringUTFRegion(jsysroot, 0, len, sysroot);
-  sysroot[len] = '\0';
-  static char* flags;
-  if (asprintf (&flags, ".debug:%s", sysroot) < 0)
-    return NULL;
-
-  static Dwfl_Callbacks callbacks = {
-    &::dwfl_linux_proc_find_elf,
-    &::dwfl_standard_find_debuginfo,
-    NULL,
-    &flags,
-  };
-  ::Dwfl* dwfl = ::dwfl_begin(&callbacks);
-  ::dwfl_report_begin(dwfl);
-  ::dwfl_linux_proc_report(dwfl, (pid_t) pid);
-  // FIXME: needs to re-build the module table.
-  ::dwfl_report_end(dwfl, NULL, NULL);
-  return (gnu::gcj::RawData*)dwfl;
-}
-
-gnu::gcj::RawData*
-lib::dwfl::Dwfl::dwflBegin(jstring jsysroot)
-{
-  int len = jsysroot->length ();
-  char sysroot[len+1]; 
-  JvGetStringUTFRegion(jsysroot, 0, len, sysroot);
-  sysroot[len] = '\0';
-  static char* flags;
-  if (asprintf (&flags, ".debug:%s", sysroot) < 0)
-    return NULL;
-
-  static Dwfl_Callbacks callbacks = {
-    &::dwfl_frysk_proc_find_elf,
-    &::dwfl_standard_find_debuginfo,
-    NULL,
-    &flags,
-  };
-  return (gnu::gcj::RawData*) ::dwfl_begin(&callbacks);
+jlong
+lib::dwfl::Dwfl::callbacksBegin(jstring debugInfoPath) {
+  char** path = (char**) JvMalloc(sizeof (char*));
+  int len = JvGetStringUTFLength(debugInfoPath);
+  *path = (char*)JvMalloc(len + 1);
+  JvGetStringUTFRegion(debugInfoPath, 0, len, *path);
+  (*path)[len] = '\0';
+  jlong callbacks = (jlong) JvMalloc(sizeof(Dwfl_Callbacks));
+  if (DWFL_CALLBACKS == 0) {
+    return 0;
+  }
+  DWFL_CALLBACKS->find_elf = &::dwfl_frysk_proc_find_elf;
+  DWFL_CALLBACKS->find_debuginfo = &::dwfl_standard_find_debuginfo;
+  DWFL_CALLBACKS->debuginfo_path = path;
+  return callbacks;
 }
 
 void
-lib::dwfl::Dwfl::dwfl_report_begin()
-{
-	::dwfl_report_begin(DWFL_POINTER);
+lib::dwfl::Dwfl::callbacksEnd(jlong callbacks) {
+  JvFree(*DWFL_CALLBACKS->debuginfo_path);
+  JvFree(DWFL_CALLBACKS->debuginfo_path);
+  JvFree(DWFL_CALLBACKS);
+}
+
+jlong
+lib::dwfl::Dwfl::dwflBegin(jlong callbacks) {
+  return (jlong) ::dwfl_begin(DWFL_CALLBACKS);
 }
 
 void
-lib::dwfl::Dwfl::dwfl_report_end()
-{
-	::dwfl_report_end(DWFL_POINTER, NULL, NULL);
+lib::dwfl::Dwfl::dwflEnd(jlong pointer){
+  ::dwfl_end(DWFL_POINTER);
+}
+
+void
+lib::dwfl::Dwfl::reportBegin(jlong pointer) {
+  ::dwfl_report_begin(DWFL_POINTER);
+}
+
+void
+lib::dwfl::Dwfl::reportEnd(jlong pointer) {
+  ::dwfl_report_end(DWFL_POINTER, NULL, NULL);
 }
 
 
-void
-lib::dwfl::Dwfl::dwfl_report_module(jstring moduleName, jlong low, jlong high)
-{
-	jsize len = JvGetStringUTFLength(moduleName);
-	char modName[len+1]; 
+jlong
+lib::dwfl::Dwfl::reportModule(jlong pointer, jstring moduleName,
+			      jlong low, jlong high) {
+  jsize len = JvGetStringUTFLength(moduleName);
+  char modName[len+1]; 
 	
-	JvGetStringUTFRegion(moduleName, 0, len, modName);
-	modName[len] = '\0';
+  JvGetStringUTFRegion(moduleName, 0, len, modName);
+  modName[len] = '\0';
 	
-	::dwfl_report_module(DWFL_POINTER, modName, (::Dwarf_Addr) low, 
-	                     (::Dwarf_Addr) high);  
+  return (jlong) ::dwfl_report_module(DWFL_POINTER, modName,
+				      (::Dwarf_Addr) low, 
+				      (::Dwarf_Addr) high);  
 }
 
-void
-lib::dwfl::Dwfl::dwfl_end(){
-	::dwfl_end(DWFL_POINTER);
-}
-
-
 extern "C" int moduleCounter(Dwfl_Module *, void **, const char *,
-			      Dwarf_Addr, void *arg)
+			     Dwarf_Addr, void *arg)
 {
   int *iarg = (int *)arg;
   (*iarg)++;
@@ -218,85 +201,3 @@ struct ModuleAdderData
   DwflModuleArray *moduleArray;
   int index;
 };
-
-extern "C" int moduleAdder(Dwfl_Module *module, void **, const char *name,
-			    Dwarf_Addr, void *arg)
-{
-  ModuleAdderData *adderData = (ModuleAdderData *)arg;
-  
-  elements(adderData->moduleArray)[adderData->index++]
-    = new lib::dwfl::DwflModule((jlong)module, adderData->dwfl, JvNewStringUTF(name));
-  return DWARF_CB_OK;
-}
-
-typedef JArray<lib::dwfl::DwflModule *> DwflModuleArray;
-void
-lib::dwfl::Dwfl::dwfl_getmodules()
-{
-  int numModules = 0;
-  
-  ::dwfl_getmodules(DWFL_POINTER, moduleCounter, &numModules, 0);
-  ModuleAdderData adderData
-    = {this,
-       (DwflModuleArray *)JvNewObjectArray(numModules,
-					   &lib::dwfl::DwflModule::class$,
-					   0),
-       0};
-  ::dwfl_getmodules(DWFL_POINTER, moduleAdder, &adderData, 0);
-  this->modules = adderData.moduleArray;
-}
-
-//jlong[]
-//lib::dwfl::Dwfl::dwfl_get_modules(){
-//	
-//}
-
-//jlong[]
-//lib::dwfl::Dwfl::dwfl_getdwarf(){
-//	
-//}
-
-jlong
-lib::dwfl::Dwfl::dwfl_getsrc(jlong addr){
-	return (jlong) ::dwfl_getsrc(DWFL_POINTER, (::Dwarf_Addr) addr);
-}
-
-lib::dwfl::DwflDieBias *
-lib::dwfl::Dwfl::dwfl_addrdie(jlong addr){
-	Dwarf_Addr bias;
-	Dwarf_Die *die = ::dwfl_addrdie(DWFL_POINTER, (::Dwarf_Addr) addr, &bias);
-	
-	if(die == NULL)
-		return NULL;
-	
-	lib::dwfl::DwflDieBias *retval = new lib::dwfl::DwflDieBias();
-        
-        lib::dwfl::DwflModule* module = lib::dwfl::Dwfl::getModule(addr);
-	retval->die = factory->makeDie((jlong) die, module);
-	retval->bias = (jlong) bias;
-	
-	return retval;
-}
-
-jlong
-lib::dwfl::Dwfl::dwfl_addrmodule(jlong addr){
-	return (jlong) ::dwfl_addrmodule(DWFL_POINTER, (Dwarf_Addr) addr);	
-}
-
-lib::dwfl::DwflModule*
-lib::dwfl::Dwfl::getModule(jlong addr)
-{
-  Dwfl_Module *module = ::dwfl_addrmodule(DWFL_POINTER, (Dwarf_Addr) addr);
-
-  if (!module)
-    return 0;
-  return new lib::dwfl::DwflModule((jlong)module, this);
-}
-
-jlong
-lib::dwfl::Dwfl::dwfl_cumodule(jlong cudie)
-{
-  Dwfl_Module* module = ::dwfl_cumodule((Dwarf_Die*)cudie);
-  return (jlong)module;
-}
-
