@@ -1,6 +1,6 @@
 // This file is part of the program FRYSK.
 //
-// Copyright 2005, Red Hat Inc.
+// Copyright 2005, 2008, Red Hat Inc.
 //
 // FRYSK is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by
@@ -57,21 +57,12 @@
 #include "lib/dwfl/ElfSymbolVisibility.h"
 #include "lib/dwfl/DwarfDieFactory.h"
 #include "lib/dwfl/Dwfl.h"
-#include "lib/dwfl/DwflDieBias.h"
+#include "lib/dwfl/DwflDie.h"
 #include "lib/dwfl/DwException.h"
 
 #include "java/util/LinkedList.h"
 
-#define DWFL_MODULE_POINTER (Dwfl_Module *) this->pointer
-
-jstring
-lib::dwfl::DwflModule::getName()
-{
-  if (!name)
-    name = JvNewStringUTF(dwfl_module_info(DWFL_MODULE_POINTER,
-					   0, 0, 0, 0, 0, 0, 0));
-  return name;
-}
+#define DWFL_MODULE_POINTER ((Dwfl_Module *) pointer)
 
 lib::dwfl::ModuleElfBias*
 lib::dwfl::DwflModule::module_getelf()
@@ -82,7 +73,7 @@ lib::dwfl::DwflModule::module_getelf()
 		return NULL;
 		
 	lib::dwfl::ModuleElfBias *ret = new lib::dwfl::ModuleElfBias();
-	ret->elf = new lib::dwfl::Elf((gnu::gcj::RawData*) elf);
+	ret->elf = new lib::dwfl::Elf((jlong) elf);
 	ret->bias = (jlong) bias;
 		
 	return ret;	
@@ -110,7 +101,7 @@ lib::dwfl::DwflModule::getLines(jstring filename, jint lineno, jint column)
       for (size_t i = 0; i < nsrcs; i++)
 	{
 	  lib::dwfl::DwflLine *line = new lib::dwfl::DwflLine((jlong)srcsp[i],
-							  getParent());
+							      this);
 	  elements(array)[i] = line;
 	}
       std::free(srcsp);
@@ -135,9 +126,9 @@ namespace {
       = ElfSymbolVisibility::intern(ELF64_ST_VISIBILITY(sym->st_other));
 
     symbolBuilder->symbol(name,
-			  sym->st_value,
-			  sym->st_size,
-			  type, bind, visibility);
+			  sym->st_value, sym->st_size,
+			  type, bind, visibility,
+			  sym->st_shndx != SHN_UNDEF);
   }
 }
 
@@ -324,7 +315,7 @@ lib::dwfl::DwflModule::getPLTEntries(lib::dwfl::SymbolBuilder* symbolBuilder)
       ::GElf_Addr addr = plt_addr + (i + 1) * plt_entry_size + bias;
 
       symbolBuilder->symbol(JvNewStringUTF(name), addr, plt_entry_size,
-			    NULL, NULL, NULL);
+			    NULL, NULL, NULL, true);
     }
 }
 
@@ -393,10 +384,12 @@ lib::dwfl::DwflModule::getDebuginfo()
 namespace {
   struct each_pubname_context {
     lib::dwfl::DwflModule* const dwflModule;
+    lib::dwfl::Dwfl* parent;
     Dwarf_Addr const bias;
 
-    each_pubname_context(lib::dwfl::DwflModule* m, Dwarf_Addr b)
-      : dwflModule(m), bias(b)
+    each_pubname_context(lib::dwfl::DwflModule* m, lib::dwfl::Dwfl* p,
+			 Dwarf_Addr b)
+      : dwflModule(m), parent(p), bias(b)
     {}
   };
 
@@ -404,18 +397,17 @@ namespace {
   each_pubname (Dwarf *dwarf, Dwarf_Global *gl, void* data)
   {
     each_pubname_context const* context = static_cast<each_pubname_context*>(data);
-    lib::dwfl::Dwfl* dwfl = context->dwflModule->parent;
+    lib::dwfl::Dwfl* dwfl = context->parent;
 
     Dwarf_Die* die = (Dwarf_Die*)JvMalloc(sizeof(Dwarf_Die));
 
     if (dwarf_offdie (dwarf, gl->die_offset, die) == NULL)
       throw new lib::dwfl::DwarfException(JvNewStringUTF("failed to get object die"));
-    else {
-      lib::dwfl::DwflDieBias* dwflDieBias = new lib::dwfl::DwflDieBias();
-      dwflDieBias->die = dwfl->factory->makeDie((jlong)die, context->dwflModule);
-      dwflDieBias->bias = context->bias;
-      context->dwflModule->pubNames->add(dwflDieBias);
-    }
+    else
+      {
+	lib::dwfl::DwflDie *dwdie = dwfl->factory->makeDwflDie((jlong)die, context->dwflModule);
+	context->dwflModule->pubNames->add(dwdie);
+      }
 
     return DWARF_CB_OK;
   }
@@ -429,7 +421,7 @@ lib::dwfl::DwflModule::get_pubnames()
 
   if (dwarf != NULL)
     {
-      ::each_pubname_context ctx(this, bias);
+      ::each_pubname_context ctx(this, parent, bias);
       ::dwarf_getpubnames(dwarf, each_pubname, &ctx, 0);
     }
 }
@@ -450,3 +442,64 @@ lib::dwfl::DwflModule::offdie(jlong die, jlong offset){
    
   return dwarfDie;
 }
+
+java::util::LinkedList*
+lib::dwfl::DwflModule::get_cu_dies()
+{
+	
+	java::util::LinkedList* list = new java::util::LinkedList();
+    
+    Dwarf_Die* cu;
+    Dwarf_Die lastcu;
+    Dwarf_Addr bias;
+    
+    cu = dwfl_module_nextcu((::Dwfl_Module*)this->pointer, NULL, &bias);
+    
+    fflush(stdout);
+    while ( cu != NULL){
+  	  
+      Dwarf_Die *die = (Dwarf_Die*)JvMalloc(sizeof(Dwarf_Die));
+  				
+  	  memcpy(die, cu, sizeof(*die));
+  	  lib::dwfl::DwarfDie* cuDie = lib::dwfl::DwarfDieFactory::getFactory()->makeDie((jlong)die, NULL);
+  	  cuDie->setManageDie(true);
+  	  
+  	  list->add(cuDie);
+  	  
+  	  memcpy(&lastcu, cu, sizeof(*cu));
+      cu = dwfl_module_nextcu((::Dwfl_Module*)this->pointer, &lastcu, &bias);
+      
+    }
+	  
+  return list;
+}
+
+jlong
+lib::dwfl::DwflModule::dwflModuleAddrdie(jlong pointer, jlong addr) {
+  Dwarf_Addr bias;
+  ::Dwarf_Die *die = ::dwfl_module_addrdie(DWFL_MODULE_POINTER,
+					   (Dwarf_Addr)addr, &bias);
+  return (jlong)die;
+}
+
+jlong
+lib::dwfl::DwflModule::dwflModuleGetDwarf(jlong pointer) {
+  Dwarf_Addr bias;
+  ::Dwarf* dwarf = ::dwfl_module_getdwarf(DWFL_MODULE_POINTER, &bias);
+  return (jlong)dwarf;
+}
+
+jlong
+lib::dwfl::DwflModule::dwflModuleGetBias(jlong pointer) {
+  Dwarf_Addr bias;
+  ::Dwarf* dwarf = ::dwfl_module_getdwarf(DWFL_MODULE_POINTER, &bias);
+  if (dwarf != NULL)
+    return (jlong) bias;
+  else
+    return -1;
+}
+
+jlong
+lib::dwfl::DwflModule::dwfl_module_getsrc(jlong pointer, jlong addr) {
+  return (jlong) ::dwfl_module_getsrc(DWFL_MODULE_POINTER, (Dwarf_Addr)addr);
+}
